@@ -38,7 +38,7 @@
 #include <framework/documentundoguard.hxx>
 #include <tools/diagnose_ex.h>
 #include <unotools/moduleoptions.hxx>
-#include <vcl/msgbox.hxx>
+#include <vcl/layout.hxx>
 
 #include <vector>
 #include <algorithm>
@@ -77,7 +77,7 @@ void Organize( sal_Int16 tabId )
         if (BaseWindow* pCurWin = pShell->GetCurWindow())
             aDesc = pCurWin->CreateEntryDescriptor();
 
-    Window* pParent = Application::GetDefDialogParent();
+    vcl::Window* pParent = Application::GetDefDialogParent();
     OrganizeDialog(pParent, tabId, aDesc).Execute();
 }
 
@@ -145,7 +145,7 @@ Sequence< OUString > GetMergedLibraryNames( const Reference< script::XLibraryCon
 }
 
 bool RenameModule (
-    Window* pErrorParent,
+    vcl::Window* pErrorParent,
     const ScriptDocument& rDocument,
     const OUString& rLibName,
     const OUString& rOldName,
@@ -160,7 +160,7 @@ bool RenameModule (
 
     if ( rDocument.hasModule( rLibName, rNewName ) )
     {
-        ErrorBox aError( pErrorParent, WB_OK | WB_DEF_OK, IDE_RESSTR(RID_STR_SBXNAMEALLREADYUSED2) );
+        MessageDialog aError(pErrorParent, IDE_RESSTR(RID_STR_SBXNAMEALLREADYUSED2));
         aError.Execute();
         return false;
     }
@@ -168,7 +168,7 @@ bool RenameModule (
     // #i74440
     if ( rNewName.isEmpty() )
     {
-        ErrorBox aError( pErrorParent, WB_OK | WB_DEF_OK, IDE_RESSTR(RID_STR_BADSBXNAME) );
+        MessageDialog aError(pErrorParent, IDE_RESSTR(RID_STR_BADSBXNAME));
         aError.Execute();
         return false;
     }
@@ -228,7 +228,7 @@ namespace
         // take ownership of the data
         boost::scoped_ptr< MacroExecutionData > pData( i_pData );
 
-        SAL_WARN_IF( !(pData->xMethod->GetParent()->GetFlags() & SBX_EXTSEARCH), "basctl.basicide","No EXTSEARCH!" );
+        SAL_WARN_IF( (pData->xMethod->GetParent()->GetFlags() & SBX_EXTSEARCH) == SBX_NONE, "basctl.basicide","No EXTSEARCH!" );
 
         // in case this is a document-local macro, try to protect the document's Undo Manager from
         // flawed scripts
@@ -342,7 +342,7 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
                     {
                         // error
                         bError = true;
-                        ErrorBox( NULL, WB_OK | WB_DEF_OK, IDEResId(RID_STR_ERRORCHOOSEMACRO).toString() ).Execute();
+                        MessageDialog(NULL, IDEResId(RID_STR_ERRORCHOOSEMACRO)).Execute();
                     }
                 }
             }
@@ -404,7 +404,7 @@ Sequence< OUString > GetMethodNames( const ScriptDocument& rDocument, const OUSt
         sal_uInt16 nRealCount = nCount;
         for ( sal_uInt16 i = 0; i < nCount; i++ )
         {
-            SbMethod* pMethod = (SbMethod*)pMod->GetMethods()->Get( i );
+            SbMethod* pMethod = static_cast<SbMethod*>(pMod->GetMethods()->Get( i ));
             if( pMethod->IsHidden() )
                 --nRealCount;
         }
@@ -413,7 +413,7 @@ Sequence< OUString > GetMethodNames( const ScriptDocument& rDocument, const OUSt
         sal_uInt16 iTarget = 0;
         for ( sal_uInt16 i = 0 ; i < nCount; ++i )
         {
-            SbMethod* pMethod = (SbMethod*)pMod->GetMethods()->Get( i );
+            SbMethod* pMethod = static_cast<SbMethod*>(pMod->GetMethods()->Get( i ));
             if( pMethod->IsHidden() )
                 continue;
             SAL_WARN_IF( !pMethod, "basctl.basicide","Method not found! (NULL)" );
@@ -452,7 +452,7 @@ bool HasMethod (
         SbxArray* pMethods = pMod->GetMethods();
         if ( pMethods )
         {
-            SbMethod* pMethod = (SbMethod*)pMethods->Find( rMethName, SbxCLASS_METHOD );
+            SbMethod* pMethod = static_cast<SbMethod*>(pMethods->Find( rMethName, SbxCLASS_METHOD ));
             if ( pMethod && !pMethod->IsHidden() )
                 bHasMethod = true;
         }
