@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <vcl/msgbox.hxx>
+#include <vcl/layout.hxx>
 
 #include <macrodlg.hxx>
 #include <macrodlg.hrc>
@@ -48,6 +48,7 @@
 #include <com/sun/star/document/MacroExecMode.hpp>
 
 #include <map>
+#include <boost/scoped_ptr.hpp>
 
 namespace basctl
 {
@@ -58,7 +59,7 @@ using ::std::pair;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
-MacroChooser::MacroChooser( Window* pParnt, bool bCreateEntries )
+MacroChooser::MacroChooser( vcl::Window* pParnt, bool bCreateEntries )
     : SfxModalDialog(pParnt, "BasicMacroDialog", "modules/BasicIDE/ui/basicmacrodialog.ui")
     , bNewDelIsDel(true)
     // the Sfx doesn't aske the BasicManger whether modified or not
@@ -124,7 +125,7 @@ MacroChooser::MacroChooser( Window* pParnt, bool bCreateEntries )
 MacroChooser::~MacroChooser()
 {
     if ( bForceStoreBasic )
-        SFX_APP()->SaveBasicAndDialogContainer();
+        SfxGetpApp()->SaveBasicAndDialogContainer();
 }
 
 void MacroChooser::StoreMacroDescription()
@@ -231,7 +232,7 @@ short MacroChooser::Execute()
     if ( StarBASIC::IsRunning() )
         m_pCloseButton->GrabFocus();
 
-    Window* pPrevDlgParent = Application::GetDefDialogParent();
+    vcl::Window* pPrevDlgParent = Application::GetDefDialogParent();
     Application::SetDefDialogParent( this );
     short nRet = ModalDialog::Execute();
     // #57314# If the BasicIDE has been activated, don't reset the DefModalDialogParent to the inactive document.
@@ -267,7 +268,7 @@ SbMethod* MacroChooser::GetMacro()
         if ( pEntry )
         {
             OUString aMacroName( m_pMacroBox->GetEntryText( pEntry ) );
-            pMethod = (SbMethod*)pModule->GetMethods()->Find( aMacroName, SbxCLASS_METHOD );
+            pMethod = static_cast<SbMethod*>(pModule->GetMethods()->Find( aMacroName, SbxCLASS_METHOD ));
         }
     }
     return pMethod;
@@ -286,7 +287,7 @@ void MacroChooser::DeleteMacro()
 
         // mark current doc as modified:
         StarBASIC* pBasic = FindBasic(pMethod);
-        DBG_ASSERT( pBasic, "Basic?!" );
+        assert(pBasic && "Basic?!");
         BasicManager* pBasMgr = FindBasicManager( pBasic );
         DBG_ASSERT( pBasMgr, "BasMgr?" );
         ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
@@ -360,11 +361,11 @@ SbMethod* MacroChooser::CreateMacro()
             pModule = pBasic->FindModule( aModName );
         }
         else if ( pBasic->GetModules()->Count() )
-            pModule = (SbModule*)pBasic->GetModules()->Get( 0 );
+            pModule = static_cast<SbModule*>(pBasic->GetModules()->Get( 0 ));
 
         if ( !pModule )
         {
-            pModule = createModImpl( static_cast<Window*>( this ),
+            pModule = createModImpl( static_cast<vcl::Window*>( this ),
                 aDocument, *m_pBasicBox, aLibName, aModName );
         }
 
@@ -512,7 +513,7 @@ IMPL_LINK( MacroChooser, BasicSelectHdl, SvTreeListBox *, pBox )
         size_t nMacroCount = pModule->GetMethods()->Count();
         for ( size_t iMeth = 0; iMeth  < nMacroCount; iMeth++ )
         {
-            SbMethod* pMethod = (SbMethod*)pModule->GetMethods()->Get( iMeth );
+            SbMethod* pMethod = static_cast<SbMethod*>(pModule->GetMethods()->Get( iMeth ));
             if( pMethod->IsHidden() )
                 continue;
             DBG_ASSERT( pMethod, "Methode nicht gefunden! (NULL)" );
@@ -614,14 +615,14 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         {
             SbMethod* pMethod = GetMacro();
             SbModule* pModule = pMethod ? pMethod->GetModule() : NULL;
-            StarBASIC* pBasic = pModule ? (StarBASIC*)pModule->GetParent() : NULL;
+            StarBASIC* pBasic = pModule ? static_cast<StarBASIC*>(pModule->GetParent()) : NULL;
             BasicManager* pBasMgr = pBasic ? FindBasicManager(pBasic) : NULL;
             if ( pBasMgr )
             {
                 ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
                 if ( aDocument.isDocument() && !aDocument.allowMacros() )
                 {
-                    WarningBox( this, WB_OK, IDEResId(RID_STR_CANNOTRUNMACRO).toString() ).Execute();
+                    MessageDialog(this, IDEResId(RID_STR_CANNOTRUNMACRO), VCL_MESSAGE_WARNING).Execute();
                     return 0;
                 }
             }
@@ -630,7 +631,7 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         {
             if ( !IsValidSbxName(m_pMacroNameEdit->GetText()) )
             {
-                ErrorBox( this, WB_OK | WB_DEF_OK, IDEResId(RID_STR_BADSBXNAME).toString() ).Execute();
+                MessageDialog(this, IDEResId(RID_STR_BADSBXNAME)).Execute();
                 m_pMacroNameEdit->SetSelection( Selection( 0, m_pMacroNameEdit->GetText().getLength() ) );
                 m_pMacroNameEdit->GrabFocus();
                 return 0;
@@ -673,12 +674,12 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
             if ( pEntry )
                 aInfoItem.SetMethod( m_pMacroBox->GetEntryText( pEntry ) );
             StoreMacroDescription();
-            SfxAllItemSet aArgs( SFX_APP()->GetPool() );
-            SfxRequest aRequest( SID_BASICIDE_APPEAR, SFX_CALLMODE_SYNCHRON, aArgs );
-            SFX_APP()->ExecuteSlot( aRequest );
+            SfxAllItemSet aArgs( SfxGetpApp()->GetPool() );
+            SfxRequest aRequest( SID_BASICIDE_APPEAR, SfxCallMode::SYNCHRON, aArgs );
+            SfxGetpApp()->ExecuteSlot( aRequest );
 
             if (SfxDispatcher* pDispatcher = GetDispatcher())
-                pDispatcher->Execute( SID_BASICIDE_EDITMACRO, SFX_CALLMODE_ASYNCHRON, &aInfoItem, 0L );
+                pDispatcher->Execute( SID_BASICIDE_EDITMACRO, SfxCallMode::ASYNCHRON, &aInfoItem, 0L );
             EndDialog(Macro_Edit);
         }
         else
@@ -688,7 +689,7 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
                 DeleteMacro();
                 if (SfxDispatcher* pDispatcher = GetDispatcher())
                     pDispatcher->Execute( SID_BASICIDE_UPDATEMODULESOURCE,
-                                          SFX_CALLMODE_SYNCHRON, &aInfoItem, 0L );
+                                          SfxCallMode::SYNCHRON, &aInfoItem, 0L );
                 CheckButtons();
                 UpdateFields();
                 //if ( m_pMacroBox->GetCurEntry() )    // OV-Bug ?
@@ -698,7 +699,7 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
             {
                 if ( !IsValidSbxName(m_pMacroNameEdit->GetText()) )
                 {
-                    ErrorBox( this, WB_OK | WB_DEF_OK, IDEResId(RID_STR_BADSBXNAME).toString() ).Execute();
+                    MessageDialog(this, IDEResId(RID_STR_BADSBXNAME)).Execute();
                     m_pMacroNameEdit->SetSelection( Selection( 0, m_pMacroNameEdit->GetText().getLength() ) );
                     m_pMacroNameEdit->GrabFocus();
                     return 1;
@@ -709,12 +710,12 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
                     aInfoItem.SetMethod( pMethod->GetName() );
                     aInfoItem.SetModule( pMethod->GetModule()->GetName() );
                     aInfoItem.SetLib( pMethod->GetModule()->GetParent()->GetName() );
-                    SfxAllItemSet aArgs( SFX_APP()->GetPool() );
-                    SfxRequest aRequest( SID_BASICIDE_APPEAR, SFX_CALLMODE_SYNCHRON, aArgs );
-                    SFX_APP()->ExecuteSlot( aRequest );
+                    SfxAllItemSet aArgs( SfxGetpApp()->GetPool() );
+                    SfxRequest aRequest( SID_BASICIDE_APPEAR, SfxCallMode::SYNCHRON, aArgs );
+                    SfxGetpApp()->ExecuteSlot( aRequest );
 
                     if (SfxDispatcher* pDispatcher = GetDispatcher())
-                        pDispatcher->Execute( SID_BASICIDE_EDITMACRO, SFX_CALLMODE_ASYNCHRON, &aInfoItem, 0L );
+                        pDispatcher->Execute( SID_BASICIDE_EDITMACRO, SfxCallMode::ASYNCHRON, &aInfoItem, 0L );
                     StoreMacroDescription();
                     EndDialog(Macro_New);
                 }
@@ -738,17 +739,17 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         DBG_ASSERT( pMethod, "Method?" );
         OUString aComment( GetInfo( pMethod ) );
         SfxMacroInfoItem aItem( SID_MACROINFO, pBasMgr, aLib, aMod, aSub, aComment );
-        SfxAllItemSet Args( SFX_APP()->GetPool() );
-        SfxRequest aRequest( SID_CONFIG, SFX_CALLMODE_SYNCHRON, Args );
+        SfxAllItemSet Args( SfxGetpApp()->GetPool() );
+        SfxRequest aRequest( SID_CONFIG, SfxCallMode::SYNCHRON, Args );
         aRequest.AppendItem( aItem );
-        SFX_APP()->ExecuteSlot( aRequest );
+        SfxGetpApp()->ExecuteSlot( aRequest );
     }
     else if (pButton == m_pNewLibButton)
     {
         SvTreeListEntry* pCurEntry = m_pBasicBox->GetCurEntry();
         EntryDescriptor aDesc = m_pBasicBox->GetEntryDescriptor(pCurEntry);
         ScriptDocument aDocument( aDesc.GetDocument() );
-        createLibImpl( static_cast<Window*>( this ), aDocument, NULL, m_pBasicBox );
+        createLibImpl( static_cast<vcl::Window*>( this ), aDocument, NULL, m_pBasicBox );
     }
     else if (pButton == m_pNewModButton)
     {
@@ -757,7 +758,7 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         ScriptDocument aDocument( aDesc.GetDocument() );
         OUString aLibName( aDesc.GetLibName() );
         OUString aModName;
-        createModImpl( static_cast<Window*>( this ), aDocument,
+        createModImpl( static_cast<vcl::Window*>( this ), aDocument,
             *m_pBasicBox, aLibName, aModName, true );
     }
     else if (pButton == m_pOrganizeButton)
@@ -765,9 +766,9 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         StoreMacroDescription();
 
         EntryDescriptor aDesc = m_pBasicBox->GetEntryDescriptor(m_pBasicBox->FirstSelected());
-        OrganizeDialog* pDlg = new OrganizeDialog( this, 0, aDesc );
+        boost::scoped_ptr<OrganizeDialog> pDlg(new OrganizeDialog( this, 0, aDesc ));
         sal_uInt16 nRet = pDlg->Execute();
-        delete pDlg;
+        pDlg.reset();
 
         if ( nRet ) // not only closed
         {
