@@ -64,6 +64,9 @@
 #include <com/sun/star/script/ModuleSizeExceededRequest.hpp>
 
 #include <cassert>
+#include <memory>
+
+#include <boost/scoped_ptr.hpp>
 
 namespace basctl
 {
@@ -149,7 +152,7 @@ void LibLBoxString::Paint(const Point& rPos, SvTreeListBox& rDev, const SvViewDa
 } // namespace
 
 //  basctl::CheckBox
-CheckBox::CheckBox(Window* pParent, WinBits nStyle)
+CheckBox::CheckBox(vcl::Window* pParent, WinBits nStyle)
     : SvTabListBox(pParent, nStyle)
     , eMode(ObjectMode::Module)
     , m_aDocument(ScriptDocument::getApplicationScriptDocument())
@@ -160,7 +163,7 @@ CheckBox::CheckBox(Window* pParent, WinBits nStyle)
     Init();
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT Window* SAL_CALL makeCheckBox(Window *pParent, VclBuilder::stringmap &rMap)
+extern "C" SAL_DLLPUBLIC_EXPORT vcl::Window* SAL_CALL makeCheckBox(vcl::Window *pParent, VclBuilder::stringmap &rMap)
 {
     WinBits nWinBits = WB_TABSTOP;
     OString sBorder = VclBuilder::extractCustomProperty(rMap);
@@ -251,7 +254,7 @@ void CheckBox::InitEntry(SvTreeListEntry* pEntry, const OUString& rTxt,
         sal_uInt16 nCount = pEntry->ItemCount();
         for ( sal_uInt16 nCol = 1; nCol < nCount; ++nCol )
         {
-            SvLBoxString* pCol = (SvLBoxString*)pEntry->GetItem( nCol );
+            SvLBoxString* pCol = static_cast<SvLBoxString*>(pEntry->GetItem( nCol ));
             LibLBoxString* pStr = new LibLBoxString( pEntry, 0, pCol->GetText() );
             pEntry->ReplaceItem( pStr, nCol );
         }
@@ -363,7 +366,7 @@ IMPL_LINK_NOARG(NewObjectDialog, OkButtonHandler)
     return 0;
 }
 
-NewObjectDialog::NewObjectDialog(Window * pParent, ObjectMode::Mode eMode,
+NewObjectDialog::NewObjectDialog(vcl::Window * pParent, ObjectMode::Mode eMode,
     bool bCheckName)
     : ModalDialog(pParent, "NewLibDialog", "modules/BasicIDE/ui/newlibdialog.ui")
 {
@@ -395,7 +398,7 @@ NewObjectDialog::NewObjectDialog(Window * pParent, ObjectMode::Mode eMode,
 }
 
 // GotoLineDialog
-GotoLineDialog::GotoLineDialog(Window * pParent )
+GotoLineDialog::GotoLineDialog(vcl::Window * pParent )
     : ModalDialog(pParent, "GotoLineDialog",
         "modules/BasicIDE/ui/gotolinedialog.ui")
 {
@@ -427,7 +430,7 @@ IMPL_LINK_NOARG(ExportDialog, OkButtonHandler)
     return 0;
 }
 
-ExportDialog::ExportDialog(Window * pParent)
+ExportDialog::ExportDialog(vcl::Window * pParent)
     : ModalDialog(pParent, "ExportDialog",
         "modules/BasicIDE/ui/exportdialog.ui")
     , mbExportAsPackage(false)
@@ -440,7 +443,7 @@ ExportDialog::ExportDialog(Window * pParent)
 }
 
 // LibPage
-LibPage::LibPage(Window * pParent)
+LibPage::LibPage(vcl::Window * pParent)
     : TabPage(pParent, "LibPage",
         "modules/BasicIDE/ui/libpage.ui")
     , m_aCurDocument(ScriptDocument::getApplicationScriptDocument())
@@ -575,9 +578,9 @@ IMPL_LINK( LibPage, ButtonHdl, Button *, pButton )
 {
     if (pButton == m_pEditButton)
     {
-        SfxAllItemSet aArgs( SFX_APP()->GetPool() );
-        SfxRequest aRequest( SID_BASICIDE_APPEAR, SFX_CALLMODE_SYNCHRON, aArgs );
-        SFX_APP()->ExecuteSlot( aRequest );
+        SfxAllItemSet aArgs( SfxGetpApp()->GetPool() );
+        SfxRequest aRequest( SID_BASICIDE_APPEAR, SfxCallMode::SYNCHRON, aArgs );
+        SfxGetpApp()->ExecuteSlot( aRequest );
 
         SfxUsrAnyItem aDocItem( SID_BASICIDE_ARG_DOCUMENT_MODEL, makeAny( m_aCurDocument.getDocumentOrNull() ) );
         SvTreeListEntry* pCurEntry = m_pLibBox->GetCurEntry();
@@ -586,7 +589,7 @@ IMPL_LINK( LibPage, ButtonHdl, Button *, pButton )
         SfxStringItem aLibNameItem( SID_BASICIDE_ARG_LIBNAME, aLibName );
         if (SfxDispatcher* pDispatcher = GetDispatcher())
             pDispatcher->Execute( SID_BASICIDE_LIBSELECTED,
-                                    SFX_CALLMODE_ASYNCHRON, &aDocItem, &aLibNameItem, 0L );
+                                    SfxCallMode::ASYNCHRON, &aDocItem, &aLibNameItem, 0L );
         EndTabDialog( 1 );
         return 0;
     }
@@ -636,7 +639,7 @@ IMPL_LINK( LibPage, ButtonHdl, Button *, pButton )
                 bool const bProtected = xPasswd->isLibraryPasswordProtected( aLibName );
 
                 // change password dialog
-                SvxPasswordDialog* pDlg = new SvxPasswordDialog( this, true, !bProtected );
+                boost::scoped_ptr<SvxPasswordDialog> pDlg(new SvxPasswordDialog( this, true, !bProtected ));
                 pDlg->SetCheckPasswordHdl( LINK( this, LibPage, CheckPasswordHdl ) );
 
                 if ( pDlg->Execute() == RET_OK )
@@ -653,7 +656,6 @@ IMPL_LINK( LibPage, ButtonHdl, Button *, pButton )
 
                     MarkDocumentModified( m_aCurDocument );
                 }
-                delete pDlg;
             }
         }
     }
@@ -689,7 +691,7 @@ IMPL_LINK_INLINE_END( LibPage, CheckPasswordHdl, SvxPasswordDialog *, pDlg )
 
 void LibPage::NewLib()
 {
-    createLibImpl( static_cast<Window*>( this ), m_aCurDocument, m_pLibBox, NULL);
+    createLibImpl( static_cast<vcl::Window*>( this ), m_aCurDocument, m_pLibBox, NULL);
 }
 
 void LibPage::InsertLib()
@@ -775,7 +777,7 @@ void LibPage::InsertLib()
 
         if ( xModLibContImport.is() || xDlgLibContImport.is() )
         {
-            LibDialog* pLibDlg = 0;
+            boost::scoped_ptr<LibDialog> pLibDlg;
 
             Reference< script::XLibraryContainer > xModLibContImp( xModLibContImport, UNO_QUERY );
             Reference< script::XLibraryContainer > xDlgLibContImp( xDlgLibContImport, UNO_QUERY );
@@ -787,7 +789,7 @@ void LibPage::InsertLib()
                 // library import dialog
                 if ( !pLibDlg )
                 {
-                    pLibDlg = new LibDialog( this );
+                    pLibDlg.reset(new LibDialog( this ));
                     pLibDlg->SetStorageName( aURLObj.getName() );
                     pLibDlg->GetLibBox().SetMode(ObjectMode::Library);
                 }
@@ -1044,7 +1046,7 @@ void LibPage::InsertLib()
                         m_pLibBox->SetCurEntry( pFirstNew );
                 }
 
-                delete pLibDlg;
+                pLibDlg.reset();
                 if ( bChanges )
                     MarkDocumentModified( m_aCurDocument );
             }
@@ -1318,7 +1320,7 @@ void LibPage::DeleteCurrent()
         SfxStringItem aLibNameItem( SID_BASICIDE_ARG_LIBNAME, aLibName );
         if (SfxDispatcher* pDispatcher = GetDispatcher())
             pDispatcher->Execute( SID_BASICIDE_LIBREMOVED,
-                                  SFX_CALLMODE_SYNCHRON, &aDocItem, &aLibNameItem, 0L );
+                                  SfxCallMode::SYNCHRON, &aDocItem, &aLibNameItem, 0L );
 
         // remove library from module and dialog library containers
         if ( xModLibContainer.is() && xModLibContainer->hasByName( aOULibName ) )
@@ -1434,7 +1436,7 @@ SvTreeListEntry* LibPage::ImpInsertLibEntry( const OUString& rLibName, sal_uLong
 }
 
 // Helper function
-void createLibImpl( Window* pWin, const ScriptDocument& rDocument,
+void createLibImpl( vcl::Window* pWin, const ScriptDocument& rDocument,
                     CheckBox* pLibBox, TreeListBox* pBasicBox )
 {
     OSL_ENSURE( rDocument.isAlive(), "createLibImpl: invalid document!" );
@@ -1499,7 +1501,7 @@ void createLibImpl( Window* pWin, const ScriptDocument& rDocument,
                 SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, rDocument, aLibName, aModName, TYPE_MODULE );
                 if (SfxDispatcher* pDispatcher = GetDispatcher())
                     pDispatcher->Execute( SID_BASICIDE_SBXINSERTED,
-                                          SFX_CALLMODE_SYNCHRON, &aSbxItem, 0L );
+                                          SfxCallMode::SYNCHRON, &aSbxItem, 0L );
 
                 if( pBasicBox )
                 {
@@ -1514,7 +1516,7 @@ void createLibImpl( Window* pWin, const ScriptDocument& rDocument,
                     sal_uInt16 nMode = pBasicBox->GetMode();
                     bool bDlgMode = ( nMode & BROWSEMODE_DIALOGS ) && !( nMode & BROWSEMODE_MODULES );
                     sal_uInt16 nId = bDlgMode ? RID_IMG_DLGLIB : RID_IMG_MODLIB;
-                    o3tl::heap_ptr<Entry> e(new Entry(OBJ_TYPE_LIBRARY));
+                    std::unique_ptr<Entry> e(new Entry(OBJ_TYPE_LIBRARY));
                     SvTreeListEntry* pNewLibEntry = pBasicBox->AddEntry(
                         aLibName,
                         Image( IDEResId( nId ) ),
