@@ -970,7 +970,7 @@ bool DlgEdObj::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
 void DlgEdObj::SetDefaults()
 {
     // set parent form
-    pDlgEdForm = ((DlgEdPage*)GetPage())->GetDlgEdForm();
+    pDlgEdForm = static_cast<DlgEdPage*>(GetPage())->GetDlgEdForm();
 
     if ( pDlgEdForm )
     {
@@ -1121,7 +1121,7 @@ void DlgEdObj::EndListening(bool bRemoveListener)
     }
 }
 
-void SAL_CALL DlgEdObj::_propertyChange( const  ::com::sun::star::beans::PropertyChangeEvent& evt ) throw( ::com::sun::star::uno::RuntimeException)
+void SAL_CALL DlgEdObj::_propertyChange( const  ::com::sun::star::beans::PropertyChangeEvent& evt ) throw( ::com::sun::star::uno::RuntimeException, std::exception)
 {
     if (isListening())
     {
@@ -1400,12 +1400,12 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
 
 void DlgEdForm::UpdateStep()
 {
-    sal_uLong nObjCount;
     SdrPage* pSdrPage = GetPage();
 
-    if ( pSdrPage && ( ( nObjCount = pSdrPage->GetObjCount() ) > 0 ) )
+    if ( pSdrPage )
     {
-        for ( sal_uLong i = 0 ; i < nObjCount ; i++ )
+        const size_t nObjCount = pSdrPage->GetObjCount();
+        for ( size_t i = 0 ; i < nObjCount ; i++ )
         {
             DlgEdObj* pDlgEdObj = dynamic_cast<DlgEdObj*>(pSdrPage->GetObj(i));
             if (pDlgEdObj && !dynamic_cast<DlgEdForm*>(pDlgEdObj))
@@ -1636,7 +1636,7 @@ awt::DeviceInfo DlgEdForm::getDeviceInfo() const
     awt::DeviceInfo aDeviceInfo;
 
     DlgEditor& rEditor = GetDlgEditor();
-    Window& rWindow = rEditor.GetWindow();
+    vcl::Window& rWindow = rEditor.GetWindow();
 
     // obtain an XControl
     ::utl::SharedUNOComponent< awt::XControl > xDialogControl; // ensures auto-disposal, if needed
