@@ -18,6 +18,7 @@
  */
 
 #include <rtl/math.hxx>
+#include <osl/diagnose.h>
 
 #include <basegfx/tuple/b2dtuple.hxx>
 #include <basegfx/range/b2drange.hxx>
@@ -35,7 +36,6 @@
 #include <deque>
 #include <list>
 
-
 namespace basegfx
 {
     namespace
@@ -50,7 +50,6 @@ namespace basegfx
         class ImplPolygon;
         typedef o3tl::vector_pool<ImplPolygon> VectorOfPolygons;
 
-
         /** This class represents an active edge
 
             As the sweep line traverses across the overall area,
@@ -147,7 +146,6 @@ namespace basegfx
         // Needs to be list - various places hold ptrs to elements
         typedef std::list< ActiveEdge > ListOfEdges;
 
-
         /** Element of the sweep line event list
 
             As the sweep line traverses across the overall area,
@@ -234,7 +232,6 @@ namespace basegfx
 
         typedef std::vector< SweepLineEvent > VectorOfEvents;
 
-
         /** Smart point container for B2DMultiRange::getPolyPolygon()
 
             This class provides methods needed only here, and is used
@@ -258,7 +255,6 @@ namespace basegfx
             }
 
             void setPolygonPoolIndex( std::ptrdiff_t nIdx ) { mnIdx = nIdx; }
-            bool isFinished() const { return mbIsFinished; }
 
             /// Add point to the end of the existing points
             void append( const B2DPoint& rPoint )
@@ -304,7 +300,7 @@ namespace basegfx
                                       B2DPolyPolygon&   rRes,
                                       bool              isFinishingEdge )
             {
-                OSL_PRECOND( !isFinished(),
+                OSL_PRECOND( !mbIsFinished,
                              "ImplPolygon::intersect(): called on already finished polygon!" );
                 OSL_PRECOND( !isFinishingEdge
                              || (isFinishingEdge && &rEvent.getRect() == &rActiveEdge.getRect()),
