@@ -17,34 +17,23 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_features.h>
+
+#include <tools/debug.hxx>
 #include <tools/stream.hxx>
 #include <basic/sbx.hxx>
 #include "runtime.hxx"
-#include <vector>
+
+#include <boost/optional.hpp>
+
 using namespace std;
 
-struct SbxDim {                 // an array-dimension:
-    SbxDim* pNext;              // Link
-    sal_Int32 nLbound, nUbound; // Limitations
-    sal_Int32 nSize;            // Number of elements
-};
-
-class SbxVarEntry : public SbxVariableRef {
-public:
-    OUString* pAlias;
-    SbxVarEntry() : SbxVariableRef(), pAlias( NULL ) {}
-   ~SbxVarEntry() { delete pAlias; }
-};
-
-typedef SbxVarEntry* SbxVarEntryPtr;
-typedef vector< SbxVarEntryPtr > SbxVarEntryPtrVector;
-class SbxVarRefs : public SbxVarEntryPtrVector
+struct SbxVarEntry
 {
-public:
-    SbxVarRefs( void ) {}
+    SbxVariableRef mpVar;
+    boost::optional<OUString> maAlias;
 };
 
-
 TYPEINIT1(SbxArray,SbxBase)
 TYPEINIT1(SbxDimArray,SbxArray)
 
@@ -52,7 +41,7 @@ TYPEINIT1(SbxDimArray,SbxArray)
 
 SbxArray::SbxArray( SbxDataType t ) : SbxBase()
 {
-    pData = new SbxVarRefs;
+    mpVarEntries = new VarEntriesType;
     eType = t;
     if( t != SbxVARIANT )
         SetFlag( SBX_FIXED );
@@ -61,7 +50,7 @@ SbxArray::SbxArray( SbxDataType t ) : SbxBase()
 SbxArray::SbxArray( const SbxArray& rArray ) :
     SvRefBase( rArray ), SbxBase()
 {
-    pData = new SbxVarRefs;
+    mpVarEntries = new VarEntriesType;
     if( rArray.eType != SbxVARIANT )
         SetFlag( SBX_FIXED );
     *this = rArray;
@@ -73,28 +62,28 @@ SbxArray& SbxArray::operator=( const SbxArray& rArray )
     {
         eType = rArray.eType;
         Clear();
-        SbxVarRefs* pSrc = rArray.pData;
+        VarEntriesType* pSrc = rArray.mpVarEntries;
         for( sal_uInt32 i = 0; i < pSrc->size(); i++ )
         {
-            SbxVarEntryPtr pSrcRef = (*pSrc)[i];
-            const SbxVariable* pSrc_ = *pSrcRef;
+            SbxVarEntry* pSrcRef = (*pSrc)[i];
+            SbxVariableRef pSrc_ = pSrcRef->mpVar;
             if( !pSrc_ )
                 continue;
-            SbxVarEntryPtr pDstRef = new SbxVarEntry;
-            *((SbxVariableRef*) pDstRef) = *((SbxVariableRef*) pSrcRef);
-            if( pSrcRef->pAlias )
-            {
-                pDstRef->pAlias = new OUString( *pSrcRef->pAlias );
-            }
+            SbxVarEntry* pDstRef = new SbxVarEntry;
+            pDstRef->mpVar = pSrcRef->mpVar;
+
+            if (pSrcRef->maAlias)
+                pDstRef->maAlias.reset(*pSrcRef->maAlias);
+
             if( eType != SbxVARIANT )
             {
                 // Convert no objects
                 if( eType != SbxOBJECT || pSrc_->GetClass() != SbxCLASS_OBJECT )
                 {
-                    ((SbxVariable*) pSrc_)->Convert( eType );
+                    pSrc_->Convert(eType);
                 }
             }
-            pData->push_back( pDstRef );
+            mpVarEntries->push_back( pDstRef );
         }
     }
     return *this;
@@ -103,7 +92,7 @@ SbxArray& SbxArray::operator=( const SbxArray& rArray )
 SbxArray::~SbxArray()
 {
     Clear();
-    delete pData;
+    delete mpVarEntries;
 }
 
 SbxDataType SbxArray::GetType() const
@@ -118,23 +107,23 @@ SbxClassType SbxArray::GetClass() const
 
 void SbxArray::Clear()
 {
-    sal_uInt32 nSize = pData->size();
+    sal_uInt32 nSize = mpVarEntries->size();
     for( sal_uInt32 i = 0 ; i < nSize ; i++ )
     {
-        SbxVarEntry* pEntry = (*pData)[i];
+        SbxVarEntry* pEntry = (*mpVarEntries)[i];
         delete pEntry;
     }
-    pData->clear();
+    mpVarEntries->clear();
 }
 
 sal_uInt32 SbxArray::Count32() const
 {
-    return pData->size();
+    return mpVarEntries->size();
 }
 
 sal_uInt16 SbxArray::Count() const
 {
-    sal_uInt32 nCount = pData->size();
+    sal_uInt32 nCount = mpVarEntries->size();
     DBG_ASSERT( nCount <= SBX_MAXINDEX, "SBX: Array-Index > SBX_MAXINDEX" );
     return (sal_uInt16)nCount;
 }
@@ -149,12 +138,11 @@ SbxVariableRef& SbxArray::GetRef32( sal_uInt32 nIdx )
         SetError( SbxERR_BOUNDS );
         nIdx = 0;
     }
-    while( pData->size() <= nIdx )
+    while( mpVarEntries->size() <= nIdx )
     {
-        const SbxVarEntryPtr p = new SbxVarEntry;
-        pData->push_back( p );
+        mpVarEntries->push_back(new SbxVarEntry);
     }
-    return *((*pData)[nIdx]);
+    return (*mpVarEntries)[nIdx]->mpVar;
 }
 
 SbxVariableRef& SbxArray::GetRef( sal_uInt16 nIdx )
@@ -167,12 +155,11 @@ SbxVariableRef& SbxArray::GetRef( sal_uInt16 nIdx )
         SetError( SbxERR_BOUNDS );
         nIdx = 0;
     }
-    while( pData->size() <= nIdx )
+    while( mpVarEntries->size() <= nIdx )
     {
-        const SbxVarEntryPtr p = new SbxVarEntry;
-        pData->push_back( p );
+        mpVarEntries->push_back(new SbxVarEntry);
     }
-    return *((*pData)[nIdx]);
+    return (*mpVarEntries)[nIdx]->mpVar;
 }
 
 SbxVariable* SbxArray::Get32( sal_uInt32 nIdx )
@@ -245,23 +232,19 @@ void SbxArray::Put( SbxVariable* pVar, sal_uInt16 nIdx )
     }
 }
 
-const OUString& SbxArray::GetAlias( sal_uInt16 nIdx )
+OUString SbxArray::GetAlias( sal_uInt16 nIdx )
 {
-static const OUString sEmpty("");
-
     if( !CanRead() )
     {
         SetError( SbxERR_PROP_WRITEONLY );
-        return sEmpty;
+        return OUString();
     }
-    SbxVarEntry& rRef = (SbxVarEntry&) GetRef( nIdx );
+    SbxVarEntry& rRef = reinterpret_cast<SbxVarEntry&>(GetRef( nIdx ));
 
-    if ( !rRef.pAlias )
-    {
-        return sEmpty;
-    }
+    if (!rRef.maAlias)
+        return OUString();
 
-    return *rRef.pAlias;
+    return *rRef.maAlias;
 }
 
 void SbxArray::PutAlias( const OUString& rAlias, sal_uInt16 nIdx )
@@ -272,51 +255,44 @@ void SbxArray::PutAlias( const OUString& rAlias, sal_uInt16 nIdx )
     }
     else
     {
-        SbxVarEntry& rRef = (SbxVarEntry&) GetRef( nIdx );
-        if( !rRef.pAlias )
-        {
-            rRef.pAlias = new OUString( rAlias );
-        }
-        else
-        {
-            *rRef.pAlias = rAlias;
-        }
+        SbxVarEntry& rRef = reinterpret_cast<SbxVarEntry&>( GetRef( nIdx ) );
+        rRef.maAlias.reset(rAlias);
     }
 }
 
 void SbxArray::Insert32( SbxVariable* pVar, sal_uInt32 nIdx )
 {
-    DBG_ASSERT( pData->size() <= SBX_MAXINDEX32, "SBX: Array gets too big" );
-    if( pData->size() > SBX_MAXINDEX32 )
+    DBG_ASSERT( mpVarEntries->size() <= SBX_MAXINDEX32, "SBX: Array gets too big" );
+    if( mpVarEntries->size() > SBX_MAXINDEX32 )
     {
             return;
     }
-    SbxVarEntryPtr p = new SbxVarEntry;
+    SbxVarEntry* p = new SbxVarEntry;
     *((SbxVariableRef*) p) = pVar;
-    SbxVarEntryPtrVector::size_type nSize = pData->size();
+    size_t nSize = mpVarEntries->size();
     if( nIdx > nSize )
     {
         nIdx = nSize;
     }
     if( eType != SbxVARIANT && pVar )
     {
-        (*p)->Convert( eType );
+        p->mpVar->Convert(eType);
     }
     if( nIdx == nSize )
     {
-        pData->push_back( p );
+        mpVarEntries->push_back( p );
     }
     else
     {
-        pData->insert( pData->begin() + nIdx, p );
+        mpVarEntries->insert( mpVarEntries->begin() + nIdx, p );
     }
     SetFlag( SBX_MODIFIED );
 }
 
 void SbxArray::Insert( SbxVariable* pVar, sal_uInt16 nIdx )
 {
-    DBG_ASSERT( pData->size() <= 0x3FF0, "SBX: Array gets too big" );
-    if( pData->size() > 0x3FF0 )
+    DBG_ASSERT( mpVarEntries->size() <= 0x3FF0, "SBX: Array gets too big" );
+    if( mpVarEntries->size() > 0x3FF0 )
     {
         return;
     }
@@ -325,10 +301,10 @@ void SbxArray::Insert( SbxVariable* pVar, sal_uInt16 nIdx )
 
 void SbxArray::Remove32( sal_uInt32 nIdx )
 {
-    if( nIdx < pData->size() )
+    if( nIdx < mpVarEntries->size() )
     {
-        SbxVariableRef* pRef = (*pData)[nIdx];
-        pData->erase( pData->begin() + nIdx );
+        SbxVarEntry* pRef = (*mpVarEntries)[nIdx];
+        mpVarEntries->erase( mpVarEntries->begin() + nIdx );
         delete pRef;
         SetFlag( SBX_MODIFIED );
     }
@@ -336,10 +312,10 @@ void SbxArray::Remove32( sal_uInt32 nIdx )
 
 void SbxArray::Remove( sal_uInt16 nIdx )
 {
-    if( nIdx < pData->size() )
+    if( nIdx < mpVarEntries->size() )
     {
-        SbxVariableRef* pRef = (*pData)[nIdx];
-        pData->erase( pData->begin() + nIdx );
+        SbxVarEntry* pRef = (*mpVarEntries)[nIdx];
+        mpVarEntries->erase( mpVarEntries->begin() + nIdx );
         delete pRef;
         SetFlag( SBX_MODIFIED );
     }
@@ -349,10 +325,10 @@ void SbxArray::Remove( SbxVariable* pVar )
 {
     if( pVar )
     {
-        for( sal_uInt32 i = 0; i < pData->size(); i++ )
+        for( sal_uInt32 i = 0; i < mpVarEntries->size(); i++ )
         {
-            SbxVariableRef* pRef = (*pData)[i];
-            if( *pRef == pVar )
+            SbxVarEntry* pRef = (*mpVarEntries)[i];
+            if (&pRef->mpVar == pVar)
             {
                 Remove32( i ); break;
             }
@@ -365,42 +341,45 @@ void SbxArray::Remove( SbxVariable* pVar )
 
 void SbxArray::Merge( SbxArray* p )
 {
-    if( p )
+    if (!p)
+        return;
+
+    for (sal_uInt16 i = 0; i < p->Count(); ++i)
     {
-        sal_uInt32 nSize = p->Count();
-        for( sal_uInt32 i = 0; i < nSize; i++ )
+        SbxVarEntry* pEntry1 = (*p->mpVarEntries)[i];
+        if (!pEntry1->mpVar)
+            continue;
+
+        OUString aName = pEntry1->mpVar->GetName();
+        sal_uInt16 nHash = pEntry1->mpVar->GetHashCode();
+
+        // Is the element by the same name already inside?
+        // Then overwrite!
+        for (size_t j = 0; j < mpVarEntries->size(); ++j)
         {
-            SbxVarEntryPtr pRef1 = (*(p->pData))[i];
-            // Is the element by name already inside?
-            // Then overwrite!
-            SbxVariable* pVar = *pRef1;
-            if( pVar )
+            SbxVarEntry* pEntry2 = (*mpVarEntries)[j];
+            if (!pEntry2->mpVar)
+                continue;
+
+            if (pEntry2->mpVar->GetHashCode() == nHash &&
+                pEntry2->mpVar->GetName().equalsIgnoreAsciiCase(aName))
             {
-                OUString aName = pVar->GetName();
-                sal_uInt16 nHash = pVar->GetHashCode();
-                for( sal_uInt32 j = 0; j < pData->size(); j++ )
-                {
-                    SbxVariableRef* pRef2 = (*pData)[j];
-                    if( (*pRef2)->GetHashCode() == nHash
-                        && (*pRef2)->GetName().equalsIgnoreAsciiCase( aName ) )
-                    {
-                        *pRef2 = pVar; pRef1 = NULL;
-                        break;
-                    }
-                }
-                if( pRef1 )
-                {
-                    SbxVarEntryPtr pRef = new SbxVarEntry;
-                    const SbxVarEntryPtr pTemp = pRef;
-                    pData->push_back( pTemp );
-                    *((SbxVariableRef*) pRef) = *((SbxVariableRef*) pRef1);
-                    if( pRef1->pAlias )
-                    {
-                        pRef->pAlias = new OUString( *pRef1->pAlias );
-                    }
-                }
+                // Take this element and clear the original.
+                pEntry2->mpVar = pEntry1->mpVar;
+                pEntry1->mpVar.Clear();
+                break;
             }
         }
+
+        if (pEntry1->mpVar)
+        {
+            // We don't have element with the same name.  Add a new entry.
+            SbxVarEntry* pNewEntry = new SbxVarEntry;
+            mpVarEntries->push_back(pNewEntry);
+            pNewEntry->mpVar = pEntry1->mpVar;
+            if (pEntry1->maAlias)
+                pNewEntry->maAlias.reset(*pEntry1->maAlias);
+        }
     }
 }
 
@@ -410,42 +389,45 @@ void SbxArray::Merge( SbxArray* p )
 SbxVariable* SbxArray::FindUserData( sal_uInt32 nData )
 {
     SbxVariable* p = NULL;
-    for( sal_uInt32 i = 0; i < pData->size(); i++ )
+    for (size_t i = 0; i < mpVarEntries->size(); ++i)
     {
-        SbxVariableRef* pRef = (*pData)[i];
-        SbxVariable* pVar = *pRef;
-        if( pVar )
+        SbxVarEntry* pEntry = (*mpVarEntries)[i];
+        if (!pEntry->mpVar)
+            continue;
+
+        if (pEntry->mpVar->IsVisible() && pEntry->mpVar->GetUserData() == nData)
         {
-            if( pVar->IsVisible() && pVar->GetUserData() == nData )
+            p = &pEntry->mpVar;
+            p->ResetFlag( SBX_EXTFOUND );
+            break;  // JSM 1995-10-06
+        }
+
+        // Did we have an array/object with extended search?
+        if (pEntry->mpVar->IsSet(SBX_EXTSEARCH))
+        {
+            switch (pEntry->mpVar->GetClass())
             {
-                p = pVar;
-                p->ResetFlag( SBX_EXTFOUND );
-                break;  // JSM 1995-10-06
+                case SbxCLASS_OBJECT:
+                {
+                    // Objects are not allowed to scan their parent.
+                    SbxFlagBits nOld = pEntry->mpVar->GetFlags();
+                    pEntry->mpVar->ResetFlag(SBX_GBLSEARCH);
+                    p = static_cast<SbxObject&>(*pEntry->mpVar).FindUserData(nData);
+                    pEntry->mpVar->SetFlags(nOld);
+                }
+                break;
+                case SbxCLASS_ARRAY:
+                    // Casting SbxVariable to SbxArray?  Really?
+                    p = reinterpret_cast<SbxArray&>(*pEntry->mpVar).FindUserData(nData);
+                break;
+                default:
+                    ;
             }
-            // Did we have an array/object with extended search?
-            else if( pVar->IsSet( SBX_EXTSEARCH ) )
+
+            if (p)
             {
-                switch( pVar->GetClass() )
-                {
-                    case SbxCLASS_OBJECT:
-                    {
-                        // Objects are not allowed to scan their parent.
-                        sal_uInt16 nOld = pVar->GetFlags();
-                        pVar->ResetFlag( SBX_GBLSEARCH );
-                        p = ((SbxObject*) pVar)->FindUserData( nData );
-                        pVar->SetFlags( nOld );
-                        break;
-                    }
-                    case SbxCLASS_ARRAY:
-                        p = ((SbxArray*) pVar)->FindUserData( nData );
-                        break;
-                    default: break;
-                }
-                if( p )
-                {
-                    p->SetFlag( SBX_EXTFOUND );
-                    break;
-                }
+                p->SetFlag(SBX_EXTFOUND);
+                break;
             }
         }
     }
@@ -458,51 +440,54 @@ SbxVariable* SbxArray::FindUserData( sal_uInt32 nData )
 SbxVariable* SbxArray::Find( const OUString& rName, SbxClassType t )
 {
     SbxVariable* p = NULL;
-    sal_uInt32 nCount = pData->size();
+    sal_uInt32 nCount = mpVarEntries->size();
     if( !nCount )
         return NULL;
     bool bExtSearch = IsSet( SBX_EXTSEARCH );
     sal_uInt16 nHash = SbxVariable::MakeHashCode( rName );
     for( sal_uInt32 i = 0; i < nCount; i++ )
     {
-        SbxVariableRef* pRef = (*pData)[i];
-        SbxVariable* pVar = *pRef;
-        if( pVar && pVar->IsVisible() )
+        SbxVarEntry* pEntry = (*mpVarEntries)[i];
+        if (!pEntry->mpVar || !pEntry->mpVar->IsVisible())
+            continue;
+
+        // The very secure search works as well, if there is no hashcode!
+        sal_uInt16 nVarHash = pEntry->mpVar->GetHashCode();
+        if ( (!nVarHash || nVarHash == nHash)
+            && (t == SbxCLASS_DONTCARE || pEntry->mpVar->GetClass() == t)
+            && (pEntry->mpVar->GetName().equalsIgnoreAsciiCase(rName)))
         {
-            // The very secure search works as well, if there is no hashcode!
-            sal_uInt16 nVarHash = pVar->GetHashCode();
-            if( ( !nVarHash || nVarHash == nHash )
-                && ( t == SbxCLASS_DONTCARE || pVar->GetClass() == t )
-                && ( pVar->GetName().equalsIgnoreAsciiCase( rName ) ) )
+            p = &pEntry->mpVar;
+            p->ResetFlag(SBX_EXTFOUND);
+            break;
+        }
+
+        // Did we have an array/object with extended search?
+        if (bExtSearch && pEntry->mpVar->IsSet(SBX_EXTSEARCH))
+        {
+            switch (pEntry->mpVar->GetClass())
             {
-                p = pVar;
-                p->ResetFlag( SBX_EXTFOUND );
+                case SbxCLASS_OBJECT:
+                {
+                    // Objects are not allowed to scan their parent.
+                    SbxFlagBits nOld = pEntry->mpVar->GetFlags();
+                    pEntry->mpVar->ResetFlag(SBX_GBLSEARCH);
+                    p = static_cast<SbxObject&>(*pEntry->mpVar).Find(rName, t);
+                    pEntry->mpVar->SetFlags(nOld);
+                }
                 break;
+                case SbxCLASS_ARRAY:
+                    // Casting SbxVariable to SbxArray?  Really?
+                    p = reinterpret_cast<SbxArray&>(*pEntry->mpVar).Find(rName, t);
+                break;
+                default:
+                    ;
             }
-            // Did we have an array/object with extended search?
-            else if( bExtSearch && pVar->IsSet( SBX_EXTSEARCH ) )
+
+            if (p)
             {
-                switch( pVar->GetClass() )
-                {
-                    case SbxCLASS_OBJECT:
-                    {
-                        // Objects are not allowed to scan their parent.
-                        sal_uInt16 nOld = pVar->GetFlags();
-                        pVar->ResetFlag( SBX_GBLSEARCH );
-                        p = ((SbxObject*) pVar)->Find( rName, t );
-                        pVar->SetFlags( nOld );
-                        break;
-                    }
-                    case SbxCLASS_ARRAY:
-                        p = ((SbxArray*) pVar)->Find( rName, t );
-                        break;
-                    default: break;
-                }
-                if( p )
-                {
-                    p->SetFlag( SBX_EXTFOUND );
-                    break;
-                }
+                p->SetFlag(SBX_EXTFOUND);
+                break;
             }
         }
     }
@@ -514,7 +499,7 @@ bool SbxArray::LoadData( SvStream& rStrm, sal_uInt16 nVer )
     sal_uInt16 nElem;
     Clear();
     bool bRes = true;
-    sal_uInt16 f = nFlags;
+    SbxFlagBits f = nFlags;
     nFlags |= SBX_WRITE;
     rStrm.ReadUInt16( nElem );
     nElem &= 0x7FFF;
@@ -522,7 +507,7 @@ bool SbxArray::LoadData( SvStream& rStrm, sal_uInt16 nVer )
     {
         sal_uInt16 nIdx;
         rStrm.ReadUInt16( nIdx );
-        SbxVariable* pVar = (SbxVariable*) Load( rStrm );
+        SbxVariable* pVar = static_cast<SbxVariable*>(Load( rStrm ));
         if( pVar )
         {
             SbxVariableRef& rRef = GetRef( nIdx );
@@ -545,22 +530,20 @@ bool SbxArray::StoreData( SvStream& rStrm ) const
     sal_uInt32 nElem = 0;
     sal_uInt32 n;
     // Which elements are even defined?
-    for( n = 0; n < pData->size(); n++ )
+    for( n = 0; n < mpVarEntries->size(); n++ )
     {
-        SbxVariableRef* pRef = (*pData)[n];
-        SbxVariable* p = *pRef;
-        if( p && !( p->GetFlags() & SBX_DONTSTORE ) )
+        SbxVarEntry* pEntry = (*mpVarEntries)[n];
+        if (pEntry->mpVar && (pEntry->mpVar->GetFlags() & SBX_DONTSTORE) == SBX_NONE)
             nElem++;
     }
-    rStrm.WriteUInt16( (sal_uInt16) nElem );
-    for( n = 0; n < pData->size(); n++ )
+    rStrm.WriteUInt16( nElem );
+    for( n = 0; n < mpVarEntries->size(); n++ )
     {
-        SbxVariableRef* pRef = (*pData)[n];
-        SbxVariable* p = *pRef;
-        if( p && !( p->GetFlags() & SBX_DONTSTORE ) )
+        SbxVarEntry* pEntry = (*mpVarEntries)[n];
+        if (pEntry->mpVar && (pEntry->mpVar->GetFlags() & SBX_DONTSTORE) == SBX_NONE)
         {
-            rStrm.WriteUInt16( (sal_uInt16) n );
-            if( !p->Store( rStrm ) )
+            rStrm.WriteUInt16( n );
+            if (!pEntry->mpVar->Store(rStrm))
                 return false;
         }
     }
@@ -579,15 +562,11 @@ void SbxArray::PutDirect( SbxVariable* pVar, sal_uInt32 nIdx )
 
 SbxDimArray::SbxDimArray( SbxDataType t ) : SbxArray( t ), mbHasFixedSize( false )
 {
-    pFirst = pLast = NULL;
-    nDim = 0;
 }
 
 SbxDimArray::SbxDimArray( const SbxDimArray& rArray )
     : SvRefBase( rArray ), SbxArray( rArray.eType )
 {
-    pFirst = pLast = NULL;
-    nDim = 0;
     *this = rArray;
 }
 
@@ -596,12 +575,7 @@ SbxDimArray& SbxDimArray::operator=( const SbxDimArray& rArray )
     if( &rArray != this )
     {
         SbxArray::operator=( (const SbxArray&) rArray );
-        SbxDim* p = rArray.pFirst;
-        while( p )
-        {
-            AddDim32( p->nLbound, p->nUbound );
-            p = p->pNext;
-        }
+        m_vDimensions = rArray.m_vDimensions;
         this->mbHasFixedSize = rArray.mbHasFixedSize;
     }
     return *this;
@@ -614,15 +588,7 @@ SbxDimArray::~SbxDimArray()
 
 void SbxDimArray::Clear()
 {
-    SbxDim* p = pFirst;
-    while( p )
-    {
-        SbxDim* q = p->pNext;
-        delete p;
-        p = q;
-    }
-    pFirst = pLast = NULL;
-    nDim   = 0;
+    m_vDimensions.clear();
 }
 
 // Add a dimension
@@ -635,24 +601,15 @@ void SbxDimArray::AddDimImpl32( sal_Int32 lb, sal_Int32 ub, bool bAllowSize0 )
         eRes = SbxERR_BOUNDS;
         ub = lb;
     }
-    SbxDim* p = new SbxDim;
-    p->nLbound = lb;
-    p->nUbound = ub;
-    p->nSize   = ub - lb + 1;
-    p->pNext   = NULL;
-    if( !pFirst )
-        pFirst = pLast = p;
-    else
-        pLast->pNext = p, pLast = p;
-    nDim++;
+    SbxDim d;
+    d.nLbound = lb;
+    d.nUbound = ub;
+    d.nSize   = ub - lb + 1;
+    m_vDimensions.push_back(d);
     if( eRes )
         SetError( eRes );
 }
 
-short SbxDimArray::GetDims() const
-{
-    return nDim;
-}
 
 void SbxDimArray::AddDim( short lb, short ub )
 {
@@ -679,17 +636,15 @@ void SbxDimArray::unoAddDim32( sal_Int32 lb, sal_Int32 ub )
 
 bool SbxDimArray::GetDim32( sal_Int32 n, sal_Int32& rlb, sal_Int32& rub ) const
 {
-    if( n < 1 || n > nDim )
+    if( n < 1 || n > static_cast<sal_Int32>(m_vDimensions.size()) )
     {
         SetError( SbxERR_BOUNDS );
         rub = rlb = 0;
         return false;
     }
-    SbxDim* p = pFirst;
-    while( --n )
-        p = p->pNext;
-    rub = p->nUbound;
-    rlb = p->nLbound;
+    SbxDim d = m_vDimensions[n - 1];
+    rub = d.nUbound;
+    rlb = d.nLbound;
     return true;
 }
 
@@ -697,6 +652,8 @@ bool SbxDimArray::GetDim( short n, short& rlb, short& rub ) const
 {
     sal_Int32 rlb32, rub32;
     bool bRet = GetDim32( n, rlb32, rub32 );
+    rub = (short)rub32;
+    rlb = (short)rlb32;
     if( bRet )
     {
         if( rlb32 < -SBX_MAXINDEX || rub32 > SBX_MAXINDEX )
@@ -704,8 +661,6 @@ bool SbxDimArray::GetDim( short n, short& rlb, short& rub ) const
             SetError( SbxERR_BOUNDS );
             return false;
         }
-        rub = (short)rub32;
-        rlb = (short)rlb32;
     }
     return bRet;
 }
@@ -715,18 +670,20 @@ bool SbxDimArray::GetDim( short n, short& rlb, short& rub ) const
 sal_uInt32 SbxDimArray::Offset32( const sal_Int32* pIdx )
 {
     sal_uInt32 nPos = 0;
-    for( SbxDim* p = pFirst; p; p = p->pNext )
+    for( std::vector<SbxDim>::const_iterator it = m_vDimensions.begin();
+         it != m_vDimensions.end(); ++it )
     {
         sal_Int32 nIdx = *pIdx++;
-        if( nIdx < p->nLbound || nIdx > p->nUbound )
+        if( nIdx < it->nLbound || nIdx > it->nUbound )
         {
             nPos = (sal_uInt32)SBX_MAXINDEX32 + 1; break;
         }
-        nPos = nPos * p->nSize + nIdx - p->nLbound;
+        nPos = nPos * it->nSize + nIdx - it->nLbound;
     }
-    if( nDim == 0 || nPos > SBX_MAXINDEX32 )
+    if( m_vDimensions.empty() || nPos > SBX_MAXINDEX32 )
     {
-        SetError( SbxERR_BOUNDS ); nPos = 0;
+        SetError( SbxERR_BOUNDS );
+        nPos = 0;
     }
     return nPos;
 }
@@ -734,18 +691,21 @@ sal_uInt32 SbxDimArray::Offset32( const sal_Int32* pIdx )
 sal_uInt16 SbxDimArray::Offset( const short* pIdx )
 {
     long nPos = 0;
-    for( SbxDim* p = pFirst; p; p = p->pNext )
+    for( std::vector<SbxDim>::const_iterator it = m_vDimensions.begin();
+         it != m_vDimensions.end(); ++it )
     {
         short nIdx = *pIdx++;
-        if( nIdx < p->nLbound || nIdx > p->nUbound )
+        if( nIdx < it->nLbound || nIdx > it->nUbound )
         {
-            nPos = SBX_MAXINDEX + 1; break;
+            nPos = SBX_MAXINDEX + 1;
+            break;
         }
-        nPos = nPos * p->nSize + nIdx - p->nLbound;
+        nPos = nPos * it->nSize + nIdx - it->nLbound;
     }
-    if( nDim == 0 || nPos > SBX_MAXINDEX )
+    if( m_vDimensions.empty() || nPos > SBX_MAXINDEX )
     {
-        SetError( SbxERR_BOUNDS ); nPos = 0;
+        SetError( SbxERR_BOUNDS );
+        nPos = 0;
     }
     return (sal_uInt16) nPos;
 }
@@ -770,31 +730,35 @@ void SbxDimArray::Put32( SbxVariable* p, const sal_Int32* pIdx  )
     SbxArray::Put32( p, Offset32( pIdx ) );
 }
 
-
 // Element-Number with the help of Parameter-Array
-
 sal_uInt32 SbxDimArray::Offset32( SbxArray* pPar )
 {
-#ifndef DISABLE_SCRIPTING
-    if( nDim == 0 || !pPar || ( ( nDim != ( pPar->Count() - 1 ) ) && SbiRuntime::isVBAEnabled() ) )
+#if HAVE_FEATURE_SCRIPTING
+    if (m_vDimensions.empty() || !pPar ||
+        ((m_vDimensions.size() != sal::static_int_cast<size_t>(pPar->Count() - 1))
+            && SbiRuntime::isVBAEnabled()))
     {
-        SetError( SbxERR_BOUNDS ); return 0;
+        SetError( SbxERR_BOUNDS );
+        return 0;
     }
 #endif
     sal_uInt32 nPos = 0;
     sal_uInt16 nOff = 1;    // Non element 0!
-    for( SbxDim* p = pFirst; p && !IsError(); p = p->pNext )
+    for( std::vector<SbxDim>::const_iterator it = m_vDimensions.begin();
+         it != m_vDimensions.end() && !IsError(); ++it )
     {
         sal_Int32 nIdx = pPar->Get( nOff++ )->GetLong();
-        if( nIdx < p->nLbound || nIdx > p->nUbound )
+        if( nIdx < it->nLbound || nIdx > it->nUbound )
         {
-            nPos = (sal_uInt32) SBX_MAXINDEX32+1; break;
+            nPos = (sal_uInt32) SBX_MAXINDEX32+1;
+            break;
         }
-        nPos = nPos * p->nSize + nIdx - p->nLbound;
+        nPos = nPos * it->nSize + nIdx - it->nLbound;
     }
     if( nPos > (sal_uInt32) SBX_MAXINDEX32 )
     {
-        SetError( SbxERR_BOUNDS ); nPos = 0;
+        SetError( SbxERR_BOUNDS );
+        nPos = 0;
     }
     return nPos;
 }
@@ -810,7 +774,7 @@ bool SbxDimArray::LoadData( SvStream& rStrm, sal_uInt16 nVer )
     rStrm.ReadInt16( nDimension );
     for( short i = 0; i < nDimension && rStrm.GetError() == SVSTREAM_OK; i++ )
     {
-        sal_Int16 lb, ub;
+        sal_Int16 lb(0), ub(0);
         rStrm.ReadInt16( lb ).ReadInt16( ub );
         AddDim( lb, ub );
     }
@@ -819,12 +783,12 @@ bool SbxDimArray::LoadData( SvStream& rStrm, sal_uInt16 nVer )
 
 bool SbxDimArray::StoreData( SvStream& rStrm ) const
 {
-    rStrm.WriteInt16( (sal_Int16) nDim );
-    for( short i = 0; i < nDim; i++ )
+    rStrm.WriteInt16(  m_vDimensions.size() );
+    for( short i = 0; i < static_cast<short>(m_vDimensions.size()); i++ )
     {
         short lb, ub;
         GetDim( i, lb, ub );
-        rStrm.WriteInt16( (sal_Int16) lb ).WriteInt16( (sal_Int16) ub );
+        rStrm.WriteInt16( lb ).WriteInt16( ub );
     }
     return SbxArray::StoreData( rStrm );
 }
