@@ -92,7 +92,7 @@ SbxVariable* SbxCollection::FindUserData( sal_uInt32 nData )
 {
     if( GetParameters() )
     {
-        SbxObject* pObj = (SbxObject*) GetObject();
+        SbxObject* pObj = static_cast<SbxObject*>(GetObject());
         return pObj ? pObj->FindUserData( nData ) : NULL;
     }
     else
@@ -105,7 +105,7 @@ SbxVariable* SbxCollection::Find( const OUString& rName, SbxClassType t )
 {
     if( GetParameters() )
     {
-        SbxObject* pObj = (SbxObject*) GetObject();
+        SbxObject* pObj = static_cast<SbxObject*>(GetObject());
         return pObj ? pObj->Find( rName, t ) : NULL;
     }
     else
@@ -117,7 +117,7 @@ SbxVariable* SbxCollection::Find( const OUString& rName, SbxClassType t )
 void SbxCollection::SFX_NOTIFY( SfxBroadcaster& rCst, const TypeId& rId1,
                                 const SfxHint& rHint, const TypeId& rId2 )
 {
-    const SbxHint* p = PTR_CAST(SbxHint,&rHint);
+    const SbxHint* p = dynamic_cast<const SbxHint*>(&rHint);
     if( p )
     {
         sal_uLong nId = p->GetId();
@@ -179,7 +179,7 @@ void SbxCollection::CollAdd( SbxArray* pPar_ )
         }
         else
         {
-            Insert( (SbxObject*) pObj );
+            Insert( static_cast<SbxObject*>(pObj) );
         }
     }
 }
