@@ -83,7 +83,7 @@ static typelib_TypeClass cpp2uno_call(
         ++ovrflw;
 
         // stack space
-        OSL_ENSURE( sizeof(void *) == sizeof(sal_Int32), "### unexpected size!" );
+        static_assert(sizeof(void *) == sizeof(sal_Int32), "### unexpected size!");
         // parameters
         void ** pUnoArgs = (void **)__builtin_alloca( 4 * sizeof(void *) * nParams );
         void ** pCppArgs = pUnoArgs + nParams;
@@ -310,7 +310,7 @@ static typelib_TypeClass cpp_mediate(
         void ** gpreg, double * fpreg, void ** ovrflw,
         sal_uInt64 * pRegisterReturn /* space for register return */ )
 {
-        OSL_ENSURE( sizeof(sal_Int32)==sizeof(void *), "### unexpected!" );
+        static_assert(sizeof(sal_Int32)==sizeof(void *), "### unexpected!");
 
         // gpreg:  [ret *], this, [other gpr params]
         // fpreg:  [fpr params]
@@ -334,15 +334,23 @@ static typelib_TypeClass cpp_mediate(
 
         typelib_InterfaceTypeDescription * pTypeDescr = pCppI->getTypeDescr();
 
-        OSL_ENSURE( nFunctionIndex < pTypeDescr->nMapFunctionIndexToMemberIndex, "### illegal vtable index!" );
         if (nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex)
         {
-                throw RuntimeException( "illegal vtable index!", (XInterface *)pThis );
+            SAL_WARN(
+                "bridges",
+                "illegal " << OUString::unacquired(&pTypeDescr->aBase.pTypeName)
+                    << " vtable index " << nFunctionIndex << "/"
+                    << pTypeDescr->nMapFunctionIndexToMemberIndex);
+            throw RuntimeException(
+                ("illegal " + OUString::unacquired(&pTypeDescr->aBase.pTypeName)
+                 + " vtable index " + OUString::number(nFunctionIndex) + "/"
+                 + OUString::number(pTypeDescr->nMapFunctionIndexToMemberIndex)),
+                (XInterface *)pThis);
         }
 
         // determine called method
         sal_Int32 nMemberPos = pTypeDescr->pMapFunctionIndexToMemberIndex[nFunctionIndex];
-        OSL_ENSURE( nMemberPos < pTypeDescr->nAllMembers, "### illegal member index!" );
+        assert(nMemberPos < pTypeDescr->nAllMembers);
 
         TypeDescription aMemberDescr( pTypeDescr->ppAllMembers[nMemberPos] );
 
@@ -579,7 +587,8 @@ sal_Size bridges::cpp_uno::shared::VtableFactory::getBlockSize(
 
 bridges::cpp_uno::shared::VtableFactory::Slot *
 bridges::cpp_uno::shared::VtableFactory::initializeBlock(
-    void * block, sal_Int32 slotCount)
+    void * block, sal_Int32 slotCount, sal_Int32,
+    typelib_InterfaceTypeDescription *)
 {
     Slot * slots = mapBlockToVtable(block);
     slots[-2].fn = 0;
@@ -598,7 +607,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
     for (sal_Int32 i = 0; i < type->nMembers; ++i) {
         typelib_TypeDescription * member = 0;
         TYPELIB_DANGER_GET(&member, type->ppMembers[i]);
-        OSL_ASSERT(member != 0);
+        assert(member != 0);
         switch (member->eTypeClass) {
         case typelib_TypeClass_INTERFACE_ATTRIBUTE:
             // Getter:
@@ -631,7 +640,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
             break;
 
         default:
-            OSL_ASSERT(false);
+            assert(false);
             break;
         }
         TYPELIB_DANGER_RELEASE(member);
