@@ -40,7 +40,6 @@
 #include "share.hxx"
 
 using namespace ::osl;
-using namespace ::rtl;
 using namespace ::com::sun::star::uno;
 
 
@@ -118,7 +117,7 @@ static typelib_TypeClass cpp2uno_call(
         if ( !rParam.bOut && bridges::cpp_uno::shared::isSimpleType( rParam.pTypeRef ) ) // value
         {
             // Simple types must fit exactly one register on x86_64
-            OSL_ASSERT( bFitsRegisters && ( ( nUsedSSE == 1 && nUsedGPR == 0 ) || ( nUsedSSE == 0 && nUsedGPR == 1 ) ) );
+            assert(bFitsRegisters && ( ( nUsedSSE == 1 && nUsedGPR == 0 ) || ( nUsedSSE == 0 && nUsedGPR == 1 ) ));
 
             if ( nUsedSSE == 1 )
             {
@@ -276,16 +275,23 @@ typelib_TypeClass cpp_vtable_call(
 
     typelib_InterfaceTypeDescription * pTypeDescr = pCppI->getTypeDescr();
 
-    OSL_ENSURE( nFunctionIndex < pTypeDescr->nMapFunctionIndexToMemberIndex, "### illegal vtable index!\n" );
     if ( nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex )
     {
-        throw RuntimeException("illegal vtable index!",
-                                reinterpret_cast<XInterface *>( pCppI ) );
+        SAL_WARN(
+            "bridges",
+            "illegal " << OUString::unacquired(&pTypeDescr->aBase.pTypeName)
+                << " vtable index " << nFunctionIndex << "/"
+                << pTypeDescr->nMapFunctionIndexToMemberIndex);
+        throw RuntimeException(
+            ("illegal " + OUString::unacquired(&pTypeDescr->aBase.pTypeName)
+             + " vtable index " + OUString::number(nFunctionIndex) + "/"
+             + OUString::number(pTypeDescr->nMapFunctionIndexToMemberIndex)),
+            reinterpret_cast<XInterface *>( pCppI ) );
     }
 
     // determine called method
     sal_Int32 nMemberPos = pTypeDescr->pMapFunctionIndexToMemberIndex[nFunctionIndex];
-    OSL_ENSURE( nMemberPos < pTypeDescr->nAllMembers, "### illegal member index!\n" );
+    assert(nMemberPos < pTypeDescr->nAllMembers);
 
     TypeDescription aMemberDescr( pTypeDescr->ppAllMembers[nMemberPos] );
 
@@ -384,8 +390,6 @@ typelib_TypeClass cpp_vtable_call(
     return eRet;
 }
 
-extern "C" void privateSnippetExecutor();
-
 const int codeSnippetSize = 24;
 
 // Generate a trampoline that redirects method calls to
@@ -400,7 +404,7 @@ const int codeSnippetSize = 24;
 // unwinding info.
 unsigned char * codeSnippet( unsigned char * code,
         sal_Int32 nFunctionIndex, sal_Int32 nVtableOffset,
-        bool bHasHiddenParam ) SAL_THROW(())
+        bool bHasHiddenParam )
 {
     sal_uInt64 nOffsetAndIndex = ( ( (sal_uInt64) nVtableOffset ) << 32 ) | ( (sal_uInt64) nFunctionIndex );
 
@@ -443,7 +447,8 @@ sal_Size bridges::cpp_uno::shared::VtableFactory::getBlockSize(
 
 bridges::cpp_uno::shared::VtableFactory::Slot *
 bridges::cpp_uno::shared::VtableFactory::initializeBlock(
-    void * block, sal_Int32 slotCount)
+    void * block, sal_Int32 slotCount, sal_Int32,
+    typelib_InterfaceTypeDescription *)
 {
     Slot * slots = mapBlockToVtable(block);
     slots[-2].fn = 0;
@@ -465,7 +470,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
         typelib_TypeDescription * pTD = 0;
 
         TYPELIB_DANGER_GET( &pTD, type->ppMembers[ nPos ] );
-        OSL_ASSERT( pTD );
+        assert(pTD);
 
         if ( typelib_TypeClass_INTERFACE_ATTRIBUTE == pTD->eTypeClass )
         {
@@ -494,7 +499,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
                                 x86_64::return_in_hidden_param( pMethodTD->pReturnTypeRef ) );
         }
         else
-            OSL_ASSERT( false );
+            assert(false);
 
         TYPELIB_DANGER_RELEASE( pTD );
     }
