@@ -44,7 +44,7 @@ bool lcl_ReadNumberFormatFromItemSet( const SfxItemSet& rSet, sal_uInt16 nValueW
 {
     bool bSet = false;
     const SfxPoolItem *pItem1 = NULL;
-    if( rSet.GetItemState( nValueWhich, true, &pItem1 ) == SFX_ITEM_SET )
+    if( rSet.GetItemState( nValueWhich, true, &pItem1 ) == SfxItemState::SET )
     {
         const SfxUInt32Item * pNumItem = dynamic_cast< const SfxUInt32Item * >( pItem1 );
         if( pNumItem )
@@ -56,7 +56,7 @@ bool lcl_ReadNumberFormatFromItemSet( const SfxItemSet& rSet, sal_uInt16 nValueW
 
     rbSourceFormatMixedStateOut=true;
     const SfxPoolItem *pItem2 = NULL;
-    if( rSet.GetItemState( nSourceFormatWhich, true, &pItem2 ) == SFX_ITEM_SET )
+    if( rSet.GetItemState( nSourceFormatWhich, true, &pItem2 ) == SfxItemState::SET )
     {
         const SfxBoolItem * pBoolItem = dynamic_cast< const SfxBoolItem * >( pItem2 );
         if( pBoolItem )
@@ -73,8 +73,8 @@ void lcl_setBoolItemToCheckBox( const SfxItemSet& rInAttrs, sal_uInt16 nWhichId,
     rCheckbox.EnableTriState( false );
 
     const SfxPoolItem *pPoolItem = NULL;
-    if( rInAttrs.GetItemState(nWhichId, true, &pPoolItem) == SFX_ITEM_SET )
-        rCheckbox.Check( ((const SfxBoolItem*)pPoolItem)->GetValue() );
+    if( rInAttrs.GetItemState(nWhichId, true, &pPoolItem) == SfxItemState::SET )
+        rCheckbox.Check( static_cast<const SfxBoolItem*>(pPoolItem)->GetValue() );
     else
     {
         rCheckbox.EnableTriState( true );
@@ -84,7 +84,7 @@ void lcl_setBoolItemToCheckBox( const SfxItemSet& rInAttrs, sal_uInt16 nWhichId,
 
 }//end anonymous namespace
 
-DataLabelResources::DataLabelResources(VclBuilderContainer* pWindow, Window* pParent, const SfxItemSet& rInAttrs )
+DataLabelResources::DataLabelResources(VclBuilderContainer* pWindow, vcl::Window* pParent, const SfxItemSet& rInAttrs )
     :
     m_pNumberFormatter(0),
     m_bNumberFormatMixedState(true),
@@ -134,8 +134,8 @@ DataLabelResources::DataLabelResources(VclBuilderContainer* pWindow, Window* pPa
 
     ::com::sun::star::uno::Sequence < sal_Int32 > aAvailabelPlacementList;
     const SfxPoolItem *pPoolItem = NULL;
-    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_AVAILABLE_PLACEMENTS, true, &pPoolItem) == SFX_ITEM_SET )
-        aAvailabelPlacementList =((const SfxIntegerListItem*)pPoolItem)->GetConstSequence();
+    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_AVAILABLE_PLACEMENTS, true, &pPoolItem) == SfxItemState::SET )
+        aAvailabelPlacementList = static_cast<const SfxIntegerListItem*>(pPoolItem)->GetConstSequence();
 
     m_pLB_LabelPlacement->Clear();
     for( sal_Int32 nN=0; nN<aAvailabelPlacementList.getLength(); ++nN )
@@ -159,7 +159,7 @@ DataLabelResources::DataLabelResources(VclBuilderContainer* pWindow, Window* pPa
     m_bNumberFormatMixedState = !lcl_ReadNumberFormatFromItemSet( rInAttrs, SID_ATTR_NUMBERFORMAT_VALUE, SID_ATTR_NUMBERFORMAT_SOURCE, m_nNumberFormatForValue, m_bSourceFormatForValue, m_bSourceFormatMixedState );
     m_bPercentFormatMixedState = !lcl_ReadNumberFormatFromItemSet( rInAttrs, SCHATTR_PERCENT_NUMBERFORMAT_VALUE, SCHATTR_PERCENT_NUMBERFORMAT_SOURCE, m_nNumberFormatForPercent, m_bSourceFormatForPercent , m_bPercentSourceMixedState);
 
-    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_NO_PERCENTVALUE, true, &pPoolItem) == SFX_ITEM_SET )
+    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_NO_PERCENTVALUE, true, &pPoolItem) == SfxItemState::SET )
     {
         bool bForbidPercentValue = (static_cast< const SfxBoolItem & >( rInAttrs.Get( SCHATTR_DATADESCR_NO_PERCENTVALUE )).GetValue() );
         if( bForbidPercentValue )
@@ -266,49 +266,49 @@ void DataLabelResources::EnableControls()
     m_pBxOrientation->Enable( bEnableRotation );
 }
 
-bool DataLabelResources::FillItemSet( SfxItemSet& rOutAttrs ) const
+bool DataLabelResources::FillItemSet( SfxItemSet* rOutAttrs ) const
 {
     if( m_pCBNumber->IsChecked() )
     {
         if( !m_bNumberFormatMixedState )
-            rOutAttrs.Put( SfxUInt32Item( SID_ATTR_NUMBERFORMAT_VALUE, m_nNumberFormatForValue ));
+            rOutAttrs->Put( SfxUInt32Item( SID_ATTR_NUMBERFORMAT_VALUE, m_nNumberFormatForValue ));
         if( !m_bSourceFormatMixedState )
-            rOutAttrs.Put( SfxBoolItem( SID_ATTR_NUMBERFORMAT_SOURCE, m_bSourceFormatForValue ));
+            rOutAttrs->Put( SfxBoolItem( SID_ATTR_NUMBERFORMAT_SOURCE, m_bSourceFormatForValue ));
     }
     if( m_pCBPercent->IsChecked() )
     {
         if( !m_bPercentFormatMixedState )
-            rOutAttrs.Put( SfxUInt32Item( SCHATTR_PERCENT_NUMBERFORMAT_VALUE, m_nNumberFormatForPercent ));
+            rOutAttrs->Put( SfxUInt32Item( SCHATTR_PERCENT_NUMBERFORMAT_VALUE, m_nNumberFormatForPercent ));
         if( !m_bPercentSourceMixedState )
-            rOutAttrs.Put( SfxBoolItem( SCHATTR_PERCENT_NUMBERFORMAT_SOURCE, m_bSourceFormatForPercent ));
+            rOutAttrs->Put( SfxBoolItem( SCHATTR_PERCENT_NUMBERFORMAT_SOURCE, m_bSourceFormatForPercent ));
     }
 
     if( m_pCBNumber->GetState()!= TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_NUMBER, m_pCBNumber->IsChecked() ) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_NUMBER, m_pCBNumber->IsChecked() ) );
     if( m_pCBPercent->GetState()!= TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_PERCENTAGE, m_pCBPercent->IsChecked() ) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_PERCENTAGE, m_pCBPercent->IsChecked() ) );
     if( m_pCBCategory->GetState()!= TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_CATEGORY, m_pCBCategory->IsChecked() ) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_CATEGORY, m_pCBCategory->IsChecked() ) );
     if( m_pCBSymbol->GetState()!= TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_SYMBOL, m_pCBSymbol->IsChecked()) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_DATADESCR_SHOW_SYMBOL, m_pCBSymbol->IsChecked()) );
 
     OUString aSep = m_aEntryMap[m_pLB_Separator->GetSelectEntryPos()];
-    rOutAttrs.Put( SfxStringItem( SCHATTR_DATADESCR_SEPARATOR, aSep) );
+    rOutAttrs->Put( SfxStringItem( SCHATTR_DATADESCR_SEPARATOR, aSep) );
 
     ::std::map< sal_uInt16, sal_Int32 >::const_iterator aIt( m_aListBoxToPlacementMap.find(m_pLB_LabelPlacement->GetSelectEntryPos()) );
     if(aIt!=m_aListBoxToPlacementMap.end())
     {
         sal_Int32 nValue = aIt->second;
-        rOutAttrs.Put( SfxInt32Item( SCHATTR_DATADESCR_PLACEMENT, nValue ) );
+        rOutAttrs->Put( SfxInt32Item( SCHATTR_DATADESCR_PLACEMENT, nValue ) );
     }
 
     if( m_pLB_TextDirection->GetSelectEntryCount() > 0 )
-        rOutAttrs.Put( SfxInt32Item( EE_PARA_WRITINGDIR, m_pLB_TextDirection->GetSelectEntryValue() ) );
+        rOutAttrs->Put( SvxFrameDirectionItem( m_pLB_TextDirection->GetSelectEntryValue(), EE_PARA_WRITINGDIR ) );
 
     if( m_pDC_Dial->IsVisible() )
     {
         sal_Int32 nDegrees = m_pDC_Dial->GetRotation();
-        rOutAttrs.Put(SfxInt32Item( SCHATTR_TEXT_DEGREES, nDegrees ) );
+        rOutAttrs->Put(SfxInt32Item( SCHATTR_TEXT_DEGREES, nDegrees ) );
     }
 
     return true;
@@ -328,19 +328,18 @@ void DataLabelResources::Reset(const SfxItemSet& rInAttrs)
     m_bPercentFormatMixedState = !lcl_ReadNumberFormatFromItemSet( rInAttrs, SCHATTR_PERCENT_NUMBERFORMAT_VALUE, SCHATTR_PERCENT_NUMBERFORMAT_SOURCE, m_nNumberFormatForPercent, m_bSourceFormatForPercent ,  m_bPercentSourceMixedState);
 
     const SfxPoolItem *pPoolItem = NULL;
-    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_SEPARATOR, true, &pPoolItem) == SFX_ITEM_SET )
+    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_SEPARATOR, true, &pPoolItem) == SfxItemState::SET )
        for(sal_Int32 i=0; i < NUMBER_SEPARATORS; ++i )
        {
-          if( m_aEntryMap[i] == ((const SfxStringItem*)pPoolItem)->GetValue())
+          if( m_aEntryMap[i] == static_cast<const SfxStringItem*>(pPoolItem)->GetValue())
               m_pLB_Separator->SelectEntryPos( i );
        }
     else
         m_pLB_Separator->SelectEntryPos( 0 );
 
-
-    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_PLACEMENT, true, &pPoolItem) == SFX_ITEM_SET )
+    if( rInAttrs.GetItemState(SCHATTR_DATADESCR_PLACEMENT, true, &pPoolItem) == SfxItemState::SET )
     {
-        sal_Int32 nPlacement = ((const SfxInt32Item*)pPoolItem)->GetValue();
+        sal_Int32 nPlacement = static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
         ::std::map< sal_Int32, sal_uInt16 >::const_iterator aIt( m_aPlacementToListBoxMap.find(nPlacement) );
         if(aIt!=m_aPlacementToListBoxMap.end())
         {
@@ -353,10 +352,10 @@ void DataLabelResources::Reset(const SfxItemSet& rInAttrs)
     else
         m_pLB_LabelPlacement->SetNoSelection();
 
-    if( rInAttrs.GetItemState(EE_PARA_WRITINGDIR, true, &pPoolItem ) == SFX_ITEM_SET )
-        m_pLB_TextDirection->SelectEntryValue( SvxFrameDirection(((const SvxFrameDirectionItem*)pPoolItem)->GetValue()) );
+    if( rInAttrs.GetItemState(EE_PARA_WRITINGDIR, true, &pPoolItem ) == SfxItemState::SET )
+        m_pLB_TextDirection->SelectEntryValue( SvxFrameDirection(static_cast<const SvxFrameDirectionItem*>(pPoolItem)->GetValue()) );
 
-    if( rInAttrs.GetItemState( SCHATTR_TEXT_DEGREES, true, &pPoolItem ) == SFX_ITEM_SET )
+    if( rInAttrs.GetItemState( SCHATTR_TEXT_DEGREES, true, &pPoolItem ) == SfxItemState::SET )
     {
         sal_Int32 nDegrees = static_cast< const SfxInt32Item * >( pPoolItem )->GetValue();
         m_pDC_Dial->SetRotation( nDegrees );
