@@ -20,7 +20,7 @@
 #include "tp_AxisLabel.hxx"
 
 #include "ResId.hxx"
-#include "TabPages.hrc"
+#include "ResourceIds.hrc"
 #include "chartview/ChartSfxItemIds.hxx"
 
 #include <svx/chrtitem.hxx>
@@ -31,8 +31,8 @@
 namespace chart
 {
 
-SchAxisLabelTabPage::SchAxisLabelTabPage( Window* pParent, const SfxItemSet& rInAttrs ) :
-        SfxTabPage( pParent, "AxisLabelTabPage","modules/schart/ui/tp_axisLabel.ui", rInAttrs ),
+SchAxisLabelTabPage::SchAxisLabelTabPage( vcl::Window* pParent, const SfxItemSet& rInAttrs ) :
+        SfxTabPage( pParent, "AxisLabelTabPage","modules/schart/ui/tp_axisLabel.ui", &rInAttrs ),
 
         m_bShowStaggeringControls( true ),
 
@@ -63,7 +63,6 @@ SchAxisLabelTabPage::SchAxisLabelTabPage( Window* pParent, const SfxItemSet& rIn
     m_pOrientHlp = new svx::OrientationHelper(*m_pCtrlDial, *m_pNfRotate, *m_pCbStacked);
     m_pOrientHlp->Enable( true );
 
-
     m_pCbStacked->EnableTriState( false );
     m_pOrientHlp->AddDependentWindow( *m_pFlOrient );
     m_pOrientHlp->AddDependentWindow( *m_pFtRotate, TRISTATE_TRUE );
@@ -80,26 +79,26 @@ void SchAxisLabelTabPage::Construct()
 {
 }
 
-SfxTabPage* SchAxisLabelTabPage::Create( Window* pParent, const SfxItemSet& rAttrs )
+SfxTabPage* SchAxisLabelTabPage::Create( vcl::Window* pParent, const SfxItemSet* rAttrs )
 {
-    return new SchAxisLabelTabPage( pParent, rAttrs );
+    return new SchAxisLabelTabPage( pParent, *rAttrs );
 }
 
-bool SchAxisLabelTabPage::FillItemSet( SfxItemSet& rOutAttrs )
+bool SchAxisLabelTabPage::FillItemSet( SfxItemSet* rOutAttrs )
 {
     bool bStacked = false;
     if( m_pOrientHlp->GetStackedState() != TRISTATE_INDET )
     {
         bStacked = m_pOrientHlp->GetStackedState() == TRISTATE_TRUE;
         if( !m_bHasInitialStacking || (bStacked != m_bInitialStacking) )
-            rOutAttrs.Put( SfxBoolItem( SCHATTR_TEXT_STACKED, bStacked ) );
+            rOutAttrs->Put( SfxBoolItem( SCHATTR_TEXT_STACKED, bStacked ) );
     }
 
     if( m_pCtrlDial->HasRotation() )
     {
         sal_Int32 nDegrees = bStacked ? 0 : m_pCtrlDial->GetRotation();
         if( !m_bHasInitialDegrees || (nDegrees != m_nInitialDegrees) )
-            rOutAttrs.Put( SfxInt32Item( SCHATTR_TEXT_DEGREES, nDegrees ) );
+            rOutAttrs->Put( SfxInt32Item( SCHATTR_TEXT_DEGREES, nDegrees ) );
     }
 
     if( m_bShowStaggeringControls )
@@ -119,29 +118,29 @@ bool SchAxisLabelTabPage::FillItemSet( SfxItemSet& rOutAttrs )
             bRadioButtonChecked = false;
 
         if( bRadioButtonChecked )
-            rOutAttrs.Put( SvxChartTextOrderItem( eOrder, SCHATTR_AXIS_LABEL_ORDER ));
+            rOutAttrs->Put( SvxChartTextOrderItem( eOrder, SCHATTR_AXIS_LABEL_ORDER ));
     }
 
     if( m_pCbTextOverlap->GetState() != TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_AXIS_LABEL_OVERLAP, m_pCbTextOverlap->IsChecked() ) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_AXIS_LABEL_OVERLAP, m_pCbTextOverlap->IsChecked() ) );
     if( m_pCbTextBreak->GetState() != TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_AXIS_LABEL_BREAK, m_pCbTextBreak->IsChecked() ) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_AXIS_LABEL_BREAK, m_pCbTextBreak->IsChecked() ) );
     if( m_pCbShowDescription->GetState() != TRISTATE_INDET )
-        rOutAttrs.Put( SfxBoolItem( SCHATTR_AXIS_SHOWDESCR, m_pCbShowDescription->IsChecked() ) );
+        rOutAttrs->Put( SfxBoolItem( SCHATTR_AXIS_SHOWDESCR, m_pCbShowDescription->IsChecked() ) );
 
     if( m_pLbTextDirection->GetSelectEntryCount() > 0 )
-        rOutAttrs.Put( SfxInt32Item( EE_PARA_WRITINGDIR, m_pLbTextDirection->GetSelectEntryValue() ) );
+        rOutAttrs->Put( SvxFrameDirectionItem( m_pLbTextDirection->GetSelectEntryValue(), EE_PARA_WRITINGDIR ) );
 
     return true;
 }
 
-void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
+void SchAxisLabelTabPage::Reset( const SfxItemSet* rInAttrs )
 {
    const SfxPoolItem* pPoolItem = NULL;
 
     // show description
-    SfxItemState aState = rInAttrs.GetItemState( SCHATTR_AXIS_SHOWDESCR, false, &pPoolItem );
-    if( aState == SFX_ITEM_DONTCARE )
+    SfxItemState aState = rInAttrs->GetItemState( SCHATTR_AXIS_SHOWDESCR, false, &pPoolItem );
+    if( aState == SfxItemState::DONTCARE )
     {
         m_pCbShowDescription->EnableTriState( true );
         m_pCbShowDescription->SetState( TRISTATE_INDET );
@@ -150,11 +149,11 @@ void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
     {
         m_pCbShowDescription->EnableTriState( false );
         bool bCheck = false;
-        if( aState == SFX_ITEM_SET )
+        if( aState == SfxItemState::SET )
             bCheck = static_cast< const SfxBoolItem * >( pPoolItem )->GetValue();
         m_pCbShowDescription->Check( bCheck );
 
-        if( ( aState & SFX_ITEM_DEFAULT ) == 0 )
+        if( aState != SfxItemState::DEFAULT && aState != SfxItemState::SET )
             m_pCbShowDescription->Hide();
     }
 
@@ -162,11 +161,11 @@ void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
 
     // check new degree item
     m_nInitialDegrees = 0;
-    aState = rInAttrs.GetItemState( SCHATTR_TEXT_DEGREES, false, &pPoolItem );
-    if( aState == SFX_ITEM_SET )
+    aState = rInAttrs->GetItemState( SCHATTR_TEXT_DEGREES, false, &pPoolItem );
+    if( aState == SfxItemState::SET )
         m_nInitialDegrees = static_cast< const SfxInt32Item * >( pPoolItem )->GetValue();
 
-    m_bHasInitialDegrees = aState != SFX_ITEM_DONTCARE;
+    m_bHasInitialDegrees = aState != SfxItemState::DONTCARE;
     if( m_bHasInitialDegrees )
         m_pCtrlDial->SetRotation( m_nInitialDegrees );
     else
@@ -174,22 +173,22 @@ void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
 
     // check stacked item
     m_bInitialStacking = false;
-    aState = rInAttrs.GetItemState( SCHATTR_TEXT_STACKED, false, &pPoolItem );
-    if( aState == SFX_ITEM_SET )
+    aState = rInAttrs->GetItemState( SCHATTR_TEXT_STACKED, false, &pPoolItem );
+    if( aState == SfxItemState::SET )
         m_bInitialStacking = static_cast< const SfxBoolItem * >( pPoolItem )->GetValue();
 
-    m_bHasInitialStacking = aState != SFX_ITEM_DONTCARE;
+    m_bHasInitialStacking = aState != SfxItemState::DONTCARE;
     if( m_bHasInitialDegrees )
         m_pOrientHlp->SetStackedState( m_bInitialStacking ? TRISTATE_TRUE : TRISTATE_FALSE );
     else
         m_pOrientHlp->SetStackedState( TRISTATE_INDET );
 
-    if( rInAttrs.GetItemState( EE_PARA_WRITINGDIR, true, &pPoolItem ) == SFX_ITEM_SET )
-        m_pLbTextDirection->SelectEntryValue( SvxFrameDirection(((const SvxFrameDirectionItem*)pPoolItem)->GetValue()) );
+    if( rInAttrs->GetItemState( EE_PARA_WRITINGDIR, true, &pPoolItem ) == SfxItemState::SET )
+        m_pLbTextDirection->SelectEntryValue( SvxFrameDirection(static_cast<const SvxFrameDirectionItem*>(pPoolItem)->GetValue()) );
 
     // Text overlap ----------
-    aState = rInAttrs.GetItemState( SCHATTR_AXIS_LABEL_OVERLAP, false, &pPoolItem );
-    if( aState == SFX_ITEM_DONTCARE )
+    aState = rInAttrs->GetItemState( SCHATTR_AXIS_LABEL_OVERLAP, false, &pPoolItem );
+    if( aState == SfxItemState::DONTCARE )
     {
         m_pCbTextOverlap->EnableTriState( true );
         m_pCbTextOverlap->SetState( TRISTATE_INDET );
@@ -198,17 +197,17 @@ void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
     {
         m_pCbTextOverlap->EnableTriState( false );
         bool bCheck = false;
-        if( aState == SFX_ITEM_SET )
+        if( aState == SfxItemState::SET )
             bCheck = static_cast< const SfxBoolItem * >( pPoolItem )->GetValue();
         m_pCbTextOverlap->Check( bCheck );
 
-        if( ( aState & SFX_ITEM_DEFAULT ) == 0 )
+        if( aState != SfxItemState::DEFAULT && aState != SfxItemState::SET )
             m_pCbTextOverlap->Hide();
     }
 
     // text break ----------
-    aState = rInAttrs.GetItemState( SCHATTR_AXIS_LABEL_BREAK, false, &pPoolItem );
-    if( aState == SFX_ITEM_DONTCARE )
+    aState = rInAttrs->GetItemState( SCHATTR_AXIS_LABEL_BREAK, false, &pPoolItem );
+    if( aState == SfxItemState::DONTCARE )
     {
         m_pCbTextBreak->EnableTriState( true );
         m_pCbTextBreak->SetState( TRISTATE_INDET );
@@ -217,11 +216,11 @@ void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
     {
         m_pCbTextBreak->EnableTriState( false );
         bool bCheck = false;
-        if( aState == SFX_ITEM_SET )
+        if( aState == SfxItemState::SET )
             bCheck = static_cast< const SfxBoolItem * >( pPoolItem )->GetValue();
         m_pCbTextBreak->Check( bCheck );
 
-        if( ( aState & SFX_ITEM_DEFAULT ) == 0 )
+        if( aState != SfxItemState::DEFAULT && aState != SfxItemState::SET )
         {
             m_pCbTextBreak->Hide();
             if( ! m_pCbTextOverlap->IsVisible() )
@@ -232,8 +231,8 @@ void SchAxisLabelTabPage::Reset( const SfxItemSet& rInAttrs )
     // text order ----------
     if( m_bShowStaggeringControls )
     {
-        aState = rInAttrs.GetItemState( SCHATTR_AXIS_LABEL_ORDER, false, &pPoolItem );
-        if( aState == SFX_ITEM_SET )
+        aState = rInAttrs->GetItemState( SCHATTR_AXIS_LABEL_ORDER, false, &pPoolItem );
+        if( aState == SfxItemState::SET )
         {
             SvxChartTextOrder eOrder = static_cast< const SvxChartTextOrderItem * >( pPoolItem )->GetValue();
 
