@@ -59,14 +59,14 @@ namespace
 {
 
 // note: in xmloff this name is used to indicate usage of own data
-static const OUString lcl_aServiceName( "com.sun.star.comp.chart.InternalDataProvider" );
+static const char lcl_aServiceName[] = "com.sun.star.comp.chart.InternalDataProvider";
 
-static const OUString lcl_aCategoriesRangeName( "categories" );
-static const OUString lcl_aCategoriesLevelRangeNamePrefix( "categoriesL " ); //L <-> level
-static const OUString lcl_aCategoriesPointRangeNamePrefix( "categoriesP " ); //P <-> point
-static const OUString lcl_aCategoriesRoleName( "categories" );
-static const OUString lcl_aLabelRangePrefix( "label " );
-static const OUString lcl_aCompleteRange( "all" );
+static const char lcl_aCategoriesRangeName[] = "categories";
+static const char lcl_aCategoriesLevelRangeNamePrefix[] = "categoriesL "; //L <-> level
+static const char lcl_aCategoriesPointRangeNamePrefix[] = "categoriesP "; //P <-> point
+static const char lcl_aCategoriesRoleName[] = "categories";
+static const char lcl_aLabelRangePrefix[] = "label ";
+static const char lcl_aCompleteRange[] = "all";
 
 typedef ::std::multimap< OUString, uno::WeakReference< chart2::data::XDataSequence > >
     lcl_tSequenceMap;
@@ -343,9 +343,8 @@ InternalDataProvider::InternalDataProvider(
             {
                 vector< vector< uno::Any > > aNewCategories;//inner count is level
                 {
-                    ChartModel* pModel = dynamic_cast<ChartModel*>(xChartModel.get());
-                    assert(pModel);
-                    ExplicitCategoriesProvider aExplicitCategoriesProvider( ChartModelHelper::getFirstCoordinateSystem(xChartModel), *pModel );
+                    ChartModel& rModel = dynamic_cast<ChartModel&>(*xChartModel.get());
+                    ExplicitCategoriesProvider aExplicitCategoriesProvider(ChartModelHelper::getFirstCoordinateSystem(xChartModel), rModel);
 
                     const Sequence< Reference< chart2::data::XLabeledDataSequence> >& rSplitCategoriesList( aExplicitCategoriesProvider.getSplitCategoriesList() );
                     sal_Int32 nLevelCount = rSplitCategoriesList.getLength();
@@ -412,7 +411,7 @@ InternalDataProvider::InternalDataProvider( const InternalDataProvider & rOther
 InternalDataProvider::~InternalDataProvider()
 {}
 
-void InternalDataProvider::lcl_addDataSequenceToMap(
+void InternalDataProvider::addDataSequenceToMap(
     const OUString & rRangeRepresentation,
     const Reference< chart2::data::XDataSequence > & xSequence )
 {
@@ -422,7 +421,7 @@ void InternalDataProvider::lcl_addDataSequenceToMap(
             uno::WeakReference< chart2::data::XDataSequence >( xSequence )));
 }
 
-void InternalDataProvider::lcl_deleteMapReferences( const OUString & rRangeRepresentation )
+void InternalDataProvider::deleteMapReferences( const OUString & rRangeRepresentation )
 {
     // set sequence to deleted by setting its range to an empty string
     tSequenceMapRange aRange( m_aSequenceMap.equal_range( rRangeRepresentation ));
@@ -440,7 +439,7 @@ void InternalDataProvider::lcl_deleteMapReferences( const OUString & rRangeRepre
     m_aSequenceMap.erase( aRange.first, aRange.second );
 }
 
-void InternalDataProvider::lcl_adaptMapReferences(
+void InternalDataProvider::adaptMapReferences(
     const OUString & rOldRangeRepresentation,
     const OUString & rNewRangeRepresentation )
 {
@@ -465,116 +464,192 @@ void InternalDataProvider::lcl_adaptMapReferences(
                                   m_aSequenceMap.upper_bound( rNewRangeRepresentation )));
 }
 
-void InternalDataProvider::lcl_increaseMapReferences(
+void InternalDataProvider::increaseMapReferences(
     sal_Int32 nBegin, sal_Int32 nEnd )
 {
     for( sal_Int32 nIndex = nEnd - 1; nIndex >= nBegin; --nIndex )
     {
-        lcl_adaptMapReferences( OUString::number( nIndex ),
+        adaptMapReferences( OUString::number( nIndex ),
                             OUString::number( nIndex + 1 ));
-        lcl_adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
+        adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
                             lcl_aLabelRangePrefix + OUString::number( nIndex + 1 ));
     }
 }
 
-void InternalDataProvider::lcl_decreaseMapReferences(
+void InternalDataProvider::decreaseMapReferences(
     sal_Int32 nBegin, sal_Int32 nEnd )
 {
     for( sal_Int32 nIndex = nBegin; nIndex < nEnd; ++nIndex )
     {
-        lcl_adaptMapReferences( OUString::number( nIndex ),
+        adaptMapReferences( OUString::number( nIndex ),
                             OUString::number( nIndex - 1 ));
-        lcl_adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
+        adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
                             lcl_aLabelRangePrefix + OUString::number( nIndex - 1 ));
     }
 }
 
-Reference< chart2::data::XDataSequence > InternalDataProvider::lcl_createDataSequenceAndAddToMap(
+Reference< chart2::data::XDataSequence > InternalDataProvider::createDataSequenceAndAddToMap(
     const OUString & rRangeRepresentation )
 {
-    OUString aRangeRepresentation = rRangeRepresentation;
-    if( aRangeRepresentation.indexOf('{') >= 0 )
-    {
-        ::std::vector< double > aNewData;
-        ::std::vector< uno::Any > aNewLabels;
-        OUString    aToken;
-        sal_Int32   nCategories     = 0;
-        sal_Int32   nIndex          = 0;
-        bool        bValues         = true;
-        bool        bLabelSet       = false;
-        OUString str = aRangeRepresentation.replace('{',' ').replace('}',' ');
+    Reference<chart2::data::XDataSequence> xSeq = createDataSequenceFromArray(rRangeRepresentation, OUString());
+    if (xSeq.is())
+        return xSeq;
 
-        m_aInternalData.clearDefaultData();
-        sal_Int32 n = m_aInternalData.getColumnCount();
-        if( n )
-            n = n - 1;
-
-        do
-        {
-            // TODO: This will be problematic if ';' is used in label names
-            // '"' character also needs to be considered in such cases
-            aToken = str.getToken(0,';',nIndex);
-            if( aToken.isEmpty() )
-                break;
-            if( aToken.indexOf('"') < 0 )
-            {
-                aNewData.push_back( aToken.toDouble() );
-            }
-            else
-            {
-                aNewLabels.push_back( uno::makeAny(aToken.replace('"', ' ').trim()) );
-                if( !nCategories &&
-                   ( !m_aInternalData.getComplexColumnLabel(n).size() ||
-                     !m_aInternalData.getComplexColumnLabel(n).front().hasValue() ) )
-                {
-                    m_aInternalData.setComplexColumnLabel( n,  aNewLabels );
-                    bLabelSet = true;
-                }
-                else
-                {
-                    m_aInternalData.setComplexRowLabel(nCategories, aNewLabels);
-                    if(nCategories==1 && bLabelSet)
-                    {
-                        ::std::vector< uno::Any > aLabels;
-                        m_aInternalData.setComplexRowLabel( 0, m_aInternalData.getComplexColumnLabel( n ) );
-                        m_aInternalData.setComplexColumnLabel( n, aLabels );
-                    }
-                }
-                aNewLabels.pop_back();
-                nCategories++;
-                bValues = false;
-            }
-        } while( nIndex >= 0 );
-
-        if( bValues )
-        {
-            m_aInternalData.insertColumn( n );
-            m_aInternalData.setColumnValues( n, aNewData );
-            aRangeRepresentation = OUString::number( n );
-        }
-        else if( nCategories > 1 )
-        {
-            aRangeRepresentation = lcl_aCategoriesRangeName;
-        }
-        else
-        {
-            aRangeRepresentation = lcl_aLabelRangePrefix+OUString::number( n );
-        }
-    }
-
-    Reference< chart2::data::XDataSequence > xSeq(
-        new UncachedDataSequence( this, aRangeRepresentation ));
-    lcl_addDataSequenceToMap( aRangeRepresentation, xSeq );
+    xSeq.set(new UncachedDataSequence(this, rRangeRepresentation));
+    addDataSequenceToMap(rRangeRepresentation, xSeq);
     return xSeq;
 }
 
-Reference< chart2::data::XDataSequence > InternalDataProvider::lcl_createDataSequenceAndAddToMap(
+uno::Reference<chart2::data::XDataSequence>
+InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, const OUString& rRole )
+{
+    if (rArrayStr.indexOf('{') != 0 || rArrayStr[rArrayStr.getLength()-1] != '}')
+    {
+        // Not an array string.
+        return uno::Reference<chart2::data::XDataSequence>();
+    }
+
+    bool bAllNumeric = true;
+    uno::Reference<chart2::data::XDataSequence> xSeq;
+
+    const sal_Unicode* p = rArrayStr.getStr();
+    const sal_Unicode* pEnd = p + rArrayStr.getLength();
+    const sal_Unicode* pElem = NULL;
+    OUString aElem;
+
+    std::vector<OUString> aRawElems;
+    ++p; // Skip the first '{'.
+    --pEnd; // Skip the last '}'.
+    bool bInQuote = false;
+    for (; p != pEnd; ++p)
+    {
+        if (*p == '"')
+        {
+            bInQuote = !bInQuote;
+            if (bInQuote)
+            {
+                // Opening quote.
+                bAllNumeric = false;
+                ++p;
+                if (p == pEnd)
+                    break;
+                pElem = p;
+            }
+            else
+            {
+                // Closing quote.
+                if (pElem)
+                    aElem = OUString(pElem, p-pElem);
+                aRawElems.push_back(aElem);
+                pElem = NULL;
+                aElem.clear();
+
+                ++p; // Skip '"'.
+                if (p == pEnd)
+                    break;
+            }
+        }
+        else if (bInQuote)
+        {
+            // Do nothing.
+        }
+        else if (*p == ';')
+        {
+            // element separator.
+            if (pElem)
+                aElem = OUString(pElem, p-pElem);
+            aRawElems.push_back(aElem);
+            pElem = NULL;
+            aElem.clear();
+        }
+        else if (!pElem)
+            pElem = p;
+    }
+
+    if (pElem)
+    {
+        aElem = OUString(pElem, p-pElem);
+        aRawElems.push_back(aElem);
+    }
+
+    if (rRole == "values-y" || rRole == "values-first" || rRole == "values-last" ||
+        rRole == "values-min" || rRole == "values-max")
+    {
+        // Column values.  Append a new data column and populate it.
+
+        std::vector<double> aValues;
+        aValues.reserve(aRawElems.size());
+        for (size_t i = 0; i < aRawElems.size(); ++i)
+            aValues.push_back(aRawElems[i].toDouble());
+        sal_Int32 n = m_aInternalData.appendColumn();
+
+        m_aInternalData.setColumnValues(n, aValues);
+
+        OUString aRangeRep = OUString::number(n);
+        xSeq.set(new UncachedDataSequence(this, aRangeRep));
+        addDataSequenceToMap(aRangeRep, xSeq);
+    }
+    else if (rRole == "values-x")
+    {
+        std::vector<double> aValues;
+        aValues.reserve(aRawElems.size());
+        if (bAllNumeric)
+        {
+            for (size_t i = 0; i < aRawElems.size(); ++i)
+                aValues.push_back(aRawElems[i].toDouble());
+        }
+        else
+        {
+            for (size_t i = 0; i < aRawElems.size(); ++i)
+                aValues.push_back(i+1);
+        }
+
+        sal_Int32 n = m_aInternalData.appendColumn();
+        m_aInternalData.setColumnValues(n, aValues);
+
+        OUString aRangeRep = OUString::number(n);
+        xSeq.set(new UncachedDataSequence(this, aRangeRep));
+        addDataSequenceToMap(aRangeRep, xSeq);
+    }
+    else if (rRole == "categories")
+    {
+        // Category labels.
+
+        for (size_t i = 0; i < aRawElems.size(); ++i)
+        {
+            std::vector<uno::Any> aLabels(1, uno::makeAny(aRawElems[i]));
+            m_aInternalData.setComplexRowLabel(i, aLabels);
+        }
+
+        xSeq.set(new UncachedDataSequence(this, lcl_aCategoriesRangeName));
+        addDataSequenceToMap(lcl_aCategoriesRangeName, xSeq);
+    }
+    else if (rRole == "label")
+    {
+        // Data series label.  There should be only one element.  This always
+        // goes to the last data column.
+        sal_Int32 nColSize = m_aInternalData.getColumnCount();
+        if (!aRawElems.empty() && nColSize)
+        {
+            std::vector<uno::Any> aLabels(1, uno::makeAny(aRawElems[0]));
+            m_aInternalData.setComplexColumnLabel(nColSize-1, aLabels);
+
+            OUString aRangeRep = lcl_aLabelRangePrefix + OUString::number(nColSize-1);
+            xSeq.set(new UncachedDataSequence(this, aRangeRep));
+            addDataSequenceToMap(aRangeRep, xSeq);
+        }
+    }
+
+    return xSeq;
+}
+
+Reference< chart2::data::XDataSequence > InternalDataProvider::createDataSequenceAndAddToMap(
     const OUString & rRangeRepresentation,
     const OUString & rRole )
 {
     Reference< chart2::data::XDataSequence > xSeq(
         new UncachedDataSequence( this, rRangeRepresentation, rRole ));
-    lcl_addDataSequenceToMap( rRangeRepresentation, xSeq );
+    addDataSequenceToMap( rRangeRepresentation, xSeq );
     return xSeq;
 }
 
@@ -654,7 +729,7 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
     // categories
     if( bHasCategories )
         aResultLSeqVec.push_back(
-            new LabeledDataSequence( lcl_createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName ) ) );
+            new LabeledDataSequence( createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName ) ) );
 
     // data with labels
     ::std::vector< Reference< chart2::data::XLabeledDataSequence > > aDataVec;
@@ -663,8 +738,8 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
     {
         aDataVec.push_back(
             new LabeledDataSequence(
-                lcl_createDataSequenceAndAddToMap( OUString::number( nIdx )),
-                lcl_createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIdx ))));
+                createDataSequenceAndAddToMap( OUString::number( nIdx )),
+                createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIdx ))));
     }
 
     // attention: this data provider has the limitation that it stores
@@ -705,7 +780,7 @@ Sequence< beans::PropertyValue > SAL_CALL InternalDataProvider::detectArguments(
 {
     Sequence< beans::PropertyValue > aArguments( 4 );
     aArguments[0] = beans::PropertyValue(
-        "CellRangeRepresentation", -1, uno::makeAny( lcl_aCompleteRange ),
+        "CellRangeRepresentation", -1, uno::makeAny( OUString(lcl_aCompleteRange) ),
         beans::PropertyState_DIRECT_VALUE );
     aArguments[1] = beans::PropertyValue(
         "DataRowSource", -1, uno::makeAny(
@@ -741,30 +816,38 @@ Reference< chart2::data::XDataSequence > SAL_CALL InternalDataProvider::createDa
         OSL_ASSERT( aRangeRepresentation.equals( lcl_aCategoriesRangeName ) );//it is not expected nor implmented that only parts of the categories are really requested
 
         // categories
-        return lcl_createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName );
+        return createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName );
     }
     else if( aRangeRepresentation.match( lcl_aLabelRangePrefix ))
     {
         // label
-        sal_Int32 nIndex = aRangeRepresentation.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
-        return lcl_createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIndex ));
+        sal_Int32 nIndex = aRangeRepresentation.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
+        return createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIndex ));
     }
     else if ( aRangeRepresentation == "last" )
     {
         sal_Int32 nIndex = (m_bDataInColumns
                             ? m_aInternalData.getColumnCount()
                             : m_aInternalData.getRowCount()) - 1;
-        return lcl_createDataSequenceAndAddToMap( OUString::number( nIndex ));
+        return createDataSequenceAndAddToMap( OUString::number( nIndex ));
     }
     else if( !aRangeRepresentation.isEmpty())
     {
         // data
-        return lcl_createDataSequenceAndAddToMap( aRangeRepresentation );
+        return createDataSequenceAndAddToMap( aRangeRepresentation );
     }
 
     return Reference< chart2::data::XDataSequence >();
 }
 
+Reference<chart2::data::XDataSequence> SAL_CALL
+InternalDataProvider::createDataSequenceByValueArray(
+    const OUString& aRole, const OUString& aRangeRepresentation )
+        throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
+{
+    return createDataSequenceFromArray(aRangeRepresentation, aRole);
+}
+
 Reference< sheet::XRangeSelection > SAL_CALL InternalDataProvider::getRangeSelection()
     throw (uno::RuntimeException, std::exception)
 {
@@ -785,7 +868,7 @@ sal_Bool SAL_CALL InternalDataProvider::hasDataByRangeRepresentation( const OUSt
     }
     else if( aRange.match( lcl_aLabelRangePrefix ))
     {
-        sal_Int32 nIndex = aRange.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_Int32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         bResult = (nIndex < (m_bDataInColumns ? m_aInternalData.getColumnCount(): m_aInternalData.getRowCount()));
     }
     else
@@ -804,7 +887,7 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
 
     if( aRange.match( lcl_aLabelRangePrefix ) )
     {
-        sal_Int32 nIndex = aRange.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_Int32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         vector< uno::Any > aComplexLabel = m_bDataInColumns
             ? m_aInternalData.getComplexColumnLabel( nIndex )
             : m_aInternalData.getComplexRowLabel( nIndex );
@@ -813,7 +896,7 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
     }
     else if( aRange.match( lcl_aCategoriesPointRangeNamePrefix ) )
     {
-        sal_Int32 nPointIndex = aRange.copy( lcl_aCategoriesPointRangeNamePrefix.getLength() ).toInt32();
+        sal_Int32 nPointIndex = aRange.copy( strlen(lcl_aCategoriesPointRangeNamePrefix) ).toInt32();
         vector< uno::Any > aComplexCategory = m_bDataInColumns
             ? m_aInternalData.getComplexRowLabel( nPointIndex )
             : m_aInternalData.getComplexColumnLabel( nPointIndex );
@@ -822,7 +905,7 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
     }
     else if( aRange.match( lcl_aCategoriesLevelRangeNamePrefix ) )
     {
-        sal_Int32 nLevel = aRange.copy( lcl_aCategoriesLevelRangeNamePrefix.getLength() ).toInt32();
+        sal_Int32 nLevel = aRange.copy( strlen(lcl_aCategoriesLevelRangeNamePrefix) ).toInt32();
         vector< vector< uno::Any > > aCategories( m_bDataInColumns ? m_aInternalData.getComplexRowLabels() : m_aInternalData.getComplexColumnLabels());
         if( nLevel < lcl_getInnerLevelCount( aCategories ) )
         {
@@ -877,7 +960,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
     vector< uno::Any > aNewVector( ContainerHelper::SequenceToVector(aNewData) );
     if( aRange.match( lcl_aLabelRangePrefix ) )
     {
-        sal_uInt32 nIndex = aRange.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_uInt32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         if( m_bDataInColumns )
             m_aInternalData.setComplexColumnLabel( nIndex, aNewVector );
         else
@@ -885,7 +968,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
     }
     else if( aRange.match( lcl_aCategoriesPointRangeNamePrefix ) )
     {
-        sal_Int32 nPointIndex = aRange.copy( lcl_aCategoriesLevelRangeNamePrefix.getLength()).toInt32();
+        sal_Int32 nPointIndex = aRange.copy( strlen(lcl_aCategoriesLevelRangeNamePrefix)).toInt32();
         if( m_bDataInColumns )
             m_aInternalData.setComplexRowLabel( nPointIndex, aNewVector );
         else
@@ -893,7 +976,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
     }
     else if( aRange.match( lcl_aCategoriesLevelRangeNamePrefix ) )
     {
-        sal_Int32 nLevel = aRange.copy( lcl_aCategoriesLevelRangeNamePrefix.getLength()).toInt32();
+        sal_Int32 nLevel = aRange.copy( strlen(lcl_aCategoriesLevelRangeNamePrefix)).toInt32();
         vector< vector< uno::Any > > aComplexCategories = m_bDataInColumns ? m_aInternalData.getComplexRowLabels() : m_aInternalData.getComplexColumnLabels();
 
         //ensure equal length
@@ -942,12 +1025,12 @@ void SAL_CALL InternalDataProvider::insertSequence( ::sal_Int32 nAfterIndex )
 {
     if( m_bDataInColumns )
     {
-        lcl_increaseMapReferences( nAfterIndex + 1, m_aInternalData.getColumnCount());
+        increaseMapReferences( nAfterIndex + 1, m_aInternalData.getColumnCount());
         m_aInternalData.insertColumn( nAfterIndex );
     }
     else
     {
-        lcl_increaseMapReferences( nAfterIndex + 1, m_aInternalData.getRowCount());
+        increaseMapReferences( nAfterIndex + 1, m_aInternalData.getRowCount());
         m_aInternalData.insertRow( nAfterIndex );
     }
 }
@@ -955,16 +1038,16 @@ void SAL_CALL InternalDataProvider::insertSequence( ::sal_Int32 nAfterIndex )
 void SAL_CALL InternalDataProvider::deleteSequence( ::sal_Int32 nAtIndex )
     throw (uno::RuntimeException, std::exception)
 {
-    lcl_deleteMapReferences( OUString::number( nAtIndex ));
-    lcl_deleteMapReferences( lcl_aLabelRangePrefix + OUString::number( nAtIndex ));
+    deleteMapReferences( OUString::number( nAtIndex ));
+    deleteMapReferences( lcl_aLabelRangePrefix + OUString::number( nAtIndex ));
     if( m_bDataInColumns )
     {
-        lcl_decreaseMapReferences( nAtIndex + 1, m_aInternalData.getColumnCount());
+        decreaseMapReferences( nAtIndex + 1, m_aInternalData.getColumnCount());
         m_aInternalData.deleteColumn( nAtIndex );
     }
     else
     {
-        lcl_decreaseMapReferences( nAtIndex + 1, m_aInternalData.getRowCount());
+        decreaseMapReferences( nAtIndex + 1, m_aInternalData.getRowCount());
         m_aInternalData.deleteRow( nAtIndex );
     }
 }
@@ -1085,7 +1168,7 @@ void SAL_CALL InternalDataProvider::registerDataSequenceForChanges( const Refere
     throw (uno::RuntimeException, std::exception)
 {
     if( xSeq.is())
-        lcl_addDataSequenceToMap( xSeq->getSourceRangeRepresentation(), xSeq );
+        addDataSequenceToMap( xSeq->getSourceRangeRepresentation(), xSeq );
 }
 
 // ____ XRangeXMLConversion ____
@@ -1121,7 +1204,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeToXML( const OUString& aRang
     }
     else if( aRangeRepresentation.match( lcl_aLabelRangePrefix ))
     {
-        sal_Int32 nIndex = aRangeRepresentation.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_Int32 nIndex = aRangeRepresentation.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         aRange.aUpperLeft.bIsEmpty = false;
         aRange.aLowerRight.bIsEmpty = true;
         if( m_bDataInColumns )
@@ -1182,7 +1265,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeFromXML( const OUString& aXM
     if( !aRange.aLowerRight.bIsEmpty &&
         ( aRange.aUpperLeft.nColumn != aRange.aLowerRight.nColumn ) &&
         ( aRange.aUpperLeft.nRow != aRange.aLowerRight.nRow ) )
-        return lcl_aCompleteRange;
+        return OUString(lcl_aCompleteRange);
 
     // attention: this data provider has the limitation that it stores
     // internally if data comes from columns or rows. It is intended for
@@ -1193,7 +1276,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeFromXML( const OUString& aXM
     if( m_bDataInColumns )
     {
         if( aRange.aUpperLeft.nColumn == 0 )
-            return lcl_aCategoriesRangeName;
+            return OUString(lcl_aCategoriesRangeName);
         if( aRange.aUpperLeft.nRow == 0 )
             return lcl_aLabelRangePrefix + OUString::number( aRange.aUpperLeft.nColumn - 1 );
 
@@ -1202,7 +1285,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeFromXML( const OUString& aXM
 
     // data in rows
     if( aRange.aUpperLeft.nRow == 0 )
-        return lcl_aCategoriesRangeName;
+        return OUString(lcl_aCategoriesRangeName);
     if( aRange.aUpperLeft.nColumn == 0 )
         return lcl_aLabelRangePrefix + OUString::number( aRange.aUpperLeft.nRow - 1 );
 
@@ -1466,7 +1549,7 @@ Sequence< OUString > InternalDataProvider::getSupportedServiceNames_Static()
     return aServices;
 }
 
-APPHELPER_XSERVICEINFO_IMPL( InternalDataProvider, lcl_aServiceName );
+APPHELPER_XSERVICEINFO_IMPL( InternalDataProvider, OUString(lcl_aServiceName) );
 
 } //  namespace chart
 
