@@ -45,8 +45,8 @@ using ::osl::MutexGuard;
 namespace
 {
 
-static const OUString lcl_aImplementationName( "com.sun.star.comp.chart2.RegressionEquation" );
-static const OUString lcl_aServiceName( "com.sun.star.chart2.RegressionEquation" );
+static const char lcl_aImplementationName[] =  "com.sun.star.comp.chart2.RegressionEquation";
+static const char lcl_aServiceName[] =  "com.sun.star.chart2.RegressionEquation";
 
 enum
 {
@@ -205,7 +205,7 @@ uno::Reference< util::XCloneable > SAL_CALL RegressionEquation::createClone()
 
 // ____ OPropertySet ____
 uno::Any RegressionEquation::GetDefaultValue( sal_Int32 nHandle ) const
-    throw(beans::UnknownPropertyException)
+    throw (beans::UnknownPropertyException, uno::RuntimeException)
 {
     const tPropertyValueMap& rStaticDefaults = *StaticRegressionEquationDefaults::get();
     tPropertyValueMap::const_iterator aFound( rStaticDefaults.find( nHandle ) );
@@ -315,7 +315,7 @@ uno::Sequence< OUString > RegressionEquation::getSupportedServiceNames_Static()
 }
 
 // implement XServiceInfo methods basing upon getSupportedServiceNames_Static
-APPHELPER_XSERVICEINFO_IMPL( RegressionEquation, lcl_aImplementationName );
+APPHELPER_XSERVICEINFO_IMPL( RegressionEquation, OUString(lcl_aImplementationName) );
 
 using impl::RegressionEquation_Base;
 
