@@ -174,7 +174,7 @@ bool NetChart::impl_createLine( VDataSeries* pSeries
                 , pSeries->getPropertiesOfSeries()
                 , PropertyMapper::getPropertyNameMapForLineSeriesProperties() );
         //because of this name this line will be used for marking
-        m_pShapeFactory->setShapeName(xShape, "MarkHandles");
+        ::chart::AbstractShapeFactory::setShapeName(xShape, "MarkHandles");
     }
     return true;
 }
@@ -245,7 +245,7 @@ bool NetChart::impl_createArea( VDataSeries* pSeries
                 , pSeries->getPropertiesOfSeries()
                 , PropertyMapper::getPropertyNameMapForFilledSeriesProperties() );
     //because of this name this line will be used for marking
-    m_pShapeFactory->setShapeName(xShape, "MarkHandles");
+    ::chart::AbstractShapeFactory::setShapeName(xShape, "MarkHandles");
     return true;
 }
 
@@ -378,7 +378,6 @@ void NetChart::createShapes()
     sal_Int32 nSkippedPoints = 0;
     sal_Int32 nCreatedPoints = 0;
 
-
     bool bDateCategory = (m_pExplicitCategoriesProvider && m_pExplicitCategoriesProvider->isDateAxis());
 
     //iterate through all x values per indices
@@ -548,7 +547,6 @@ void NetChart::createShapes()
                     }
                     aSeriesFormerPointMap[pSeries] = FormerPoint(aScaledLogicPosition.PositionX, aScaledLogicPosition.PositionY, aScaledLogicPosition.PositionZ);
 
-
                     //store point information for series polygon
                     //for area and/or line (symbols only do not need this)
                     if( isValidPosition(aScaledLogicPosition) )
@@ -680,7 +678,7 @@ void NetChart::createShapes()
                                     .transformSceneToScreenPosition( aScenePosition3D ) );
                             }
 
-                            this->createDataLabel( m_xTextTarget, **aSeriesIter, nIndex
+                            createDataLabel( m_xTextTarget, **aSeriesIter, nIndex
                                             , fLogicValueForLabeDisplay
                                             , aLogicYSumMap[nAttachedAxisIndex], aScreenPosition2D, eAlignment, nOffset );
                         }
