@@ -22,7 +22,7 @@
 #include "ViewDefines.hxx"
 #include "Linear3DTransformation.hxx"
 #include "VPolarTransformation.hxx"
-#include "ShapeFactory.hxx"
+#include "AbstractShapeFactory.hxx"
 #include "PropertyMapper.hxx"
 #include "DateHelper.hxx"
 #include "defines.hxx"
@@ -34,10 +34,8 @@
 
 #include <rtl/math.hxx>
 
-//.............................................................................
 namespace chart
 {
-//.............................................................................
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
 
@@ -106,10 +104,6 @@ void PlottingPositionHelper::setScales( const std::vector< ExplicitScaleData >&
     m_bSwapXAndY = bSwapXAndYAxis;
     m_xTransformationLogicToScene = NULL;
 }
-const std::vector< ExplicitScaleData >& PlottingPositionHelper::getScales() const
-{
-    return m_aScales;
-}
 
 uno::Reference< XTransformation > PlottingPositionHelper::getTransformationScaledLogicToScene() const
 {
@@ -205,7 +199,7 @@ drawing::Position3D PlottingPositionHelper::transformScaledLogicToScene(
 
 awt::Point PlottingPositionHelper::transformSceneToScreenPosition( const drawing::Position3D& rScenePosition3D
                 , const uno::Reference< drawing::XShapes >& xSceneTarget
-                , ShapeFactory* pShapeFactory
+                , AbstractShapeFactory* pShapeFactory
                 , sal_Int32 nDimensionCount )
 {
     //@todo would like to have a cheaper method to do this transformation
@@ -247,7 +241,6 @@ void PlottingPositionHelper::transformScaledLogicToScene( drawing::PolyPolygonSh
     }
 }
 
-
 void PlottingPositionHelper::clipScaledLogicValues( double* pX, double* pY, double* pZ ) const
 {
     //get logic clip values:
@@ -323,10 +316,6 @@ drawing::Direction3D PlottingPositionHelper::getScaledLogicWidth() const
     return aRet;
 }
 
-//-----------------------------------------------------------------------------
-//-----------------------------------------------------------------------------
-//-----------------------------------------------------------------------------
-
 PolarPlottingPositionHelper::PolarPlottingPositionHelper( NormalAxis eNormalAxis )
     : m_fRadiusOffset(0.0)
     , m_fAngleDegreeOffset(90.0)
@@ -430,11 +419,6 @@ void PolarPlottingPositionHelper::setScales( const std::vector< ExplicitScaleDat
     return aRet;
 }
 
-::basegfx::B3DHomMatrix PolarPlottingPositionHelper::getUnitCartesianToScene() const
-{
-    return m_aUnitCartesianToScene;
-}
-
 uno::Reference< XTransformation > PolarPlottingPositionHelper::getTransformationScaledLogicToScene() const
 {
     if( !m_xTransformationLogicToScene.is() )
