@@ -17,29 +17,29 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "comphelper/containermultiplexer.hxx"
-#include "comphelper/uno3.hxx"
+#include <comphelper/containermultiplexer.hxx>
+#include <comphelper/uno3.hxx>
 #include <osl/diagnose.h>
-//.........................................................................
+
 namespace comphelper
 {
-//.........................................................................
+
 
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::lang;
     using namespace ::com::sun::star::container;
 
-    //=====================================================================
+
     //= OContainerListener
-    //=====================================================================
-    //---------------------------------------------------------------------
+
+
     OContainerListener::OContainerListener(::osl::Mutex& _rMutex)
         :m_pAdapter(NULL)
         ,m_rMutex(_rMutex)
     {
     }
 
-    //---------------------------------------------------------------------
+
     OContainerListener::~OContainerListener()
     {
         if (m_pAdapter)
@@ -49,27 +49,31 @@ namespace comphelper
         }
     }
 
-    //---------------------------------------------------------------------
-    void OContainerListener::_elementInserted( const ContainerEvent& /*_rEvent*/ ) throw(RuntimeException)
+
+    void OContainerListener::_elementInserted( const ContainerEvent& /*_rEvent*/ )
+        throw (RuntimeException, std::exception)
     {
     }
 
-    //---------------------------------------------------------------------
-    void OContainerListener::_elementRemoved( const ContainerEvent& ) throw(RuntimeException)
+
+    void OContainerListener::_elementRemoved( const ContainerEvent& )
+        throw (RuntimeException, std::exception)
     {
     }
 
-    //---------------------------------------------------------------------
-    void OContainerListener::_elementReplaced( const ContainerEvent& /*_rEvent*/ ) throw(RuntimeException)
+
+    void OContainerListener::_elementReplaced( const ContainerEvent& /*_rEvent*/ )
+        throw (RuntimeException, std::exception)
     {
     }
 
-    //---------------------------------------------------------------------
-    void OContainerListener::_disposing(const EventObject& ) throw( RuntimeException)
+
+    void OContainerListener::_disposing(const EventObject& )
+        throw (RuntimeException, std::exception)
     {
     }
 
-    //------------------------------------------------------------------
+
     void OContainerListener::setAdapter(OContainerListenerAdapter* pAdapter)
     {
         if (m_pAdapter)
@@ -87,10 +91,10 @@ namespace comphelper
         }
     }
 
-    //=====================================================================
+
     //= OContainerListenerAdapter
-    //=====================================================================
-    //---------------------------------------------------------------------
+
+
     OContainerListenerAdapter::OContainerListenerAdapter(OContainerListener* _pListener,
             const  Reference< XContainer >& _rxContainer)
         :m_xContainer(_rxContainer)
@@ -107,17 +111,17 @@ namespace comphelper
         }
         catch(const Exception&)
         {
-            OSL_FAIL("Exceptiopn caught!");
+            OSL_FAIL("Exception caught!");
         }
         ::comphelper::decrement(m_refCount);
     }
 
-    //---------------------------------------------------------------------
+
     OContainerListenerAdapter::~OContainerListenerAdapter()
     {
     }
 
-    //------------------------------------------------------------------
+
     void OContainerListenerAdapter::dispose()
     {
         if (m_xContainer.is())
@@ -137,8 +141,8 @@ namespace comphelper
         }
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OContainerListenerAdapter::disposing( const  EventObject& _rSource) throw(RuntimeException)
+
+    void SAL_CALL OContainerListenerAdapter::disposing( const  EventObject& _rSource) throw(RuntimeException, std::exception)
     {
         if (m_pListener)
         {
@@ -154,29 +158,29 @@ namespace comphelper
         m_pListener = NULL;
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OContainerListenerAdapter::elementInserted( const ContainerEvent& _rEvent ) throw(RuntimeException)
+
+    void SAL_CALL OContainerListenerAdapter::elementInserted( const ContainerEvent& _rEvent ) throw(RuntimeException, std::exception)
     {
         if (m_pListener && !locked())
             m_pListener->_elementInserted(_rEvent);
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OContainerListenerAdapter::elementRemoved( const ContainerEvent& _rEvent ) throw(RuntimeException)
+
+    void SAL_CALL OContainerListenerAdapter::elementRemoved( const ContainerEvent& _rEvent ) throw(RuntimeException, std::exception)
     {
         if (m_pListener && !locked())
             m_pListener->_elementRemoved(_rEvent);
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OContainerListenerAdapter::elementReplaced( const ContainerEvent& _rEvent ) throw(RuntimeException)
+
+    void SAL_CALL OContainerListenerAdapter::elementReplaced( const ContainerEvent& _rEvent ) throw(RuntimeException, std::exception)
     {
         if (m_pListener && !locked())
             m_pListener->_elementReplaced(_rEvent);
     }
 
-//.........................................................................
+
 }   // namespace comphelper
-//.........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
