@@ -176,11 +176,9 @@ namespace comphelper
     };
 
 
-    ::std::auto_ptr< IKeyPredicateLess > getStandardLessPredicate( Type const & i_type, Reference< XCollator > const & i_collator )
+    ::std::unique_ptr< IKeyPredicateLess > getStandardLessPredicate( Type const & i_type, Reference< XCollator > const & i_collator )
     {
-	SAL_WNODEPRECATED_DECLARATIONS_PUSH
-        ::std::auto_ptr< IKeyPredicateLess > pComparator;
-	SAL_WNODEPRECATED_DECLARATIONS_POP
+        ::std::unique_ptr< IKeyPredicateLess > pComparator;
         switch ( i_type.getTypeClass() )
         {
         case TypeClass_CHAR:
