@@ -50,7 +50,7 @@ namespace comphelper
         Reference< XProxyFactory > xFactory = ProxyFactory::create( m_xContext );
 
         // then the proxy itself
-        { // i36686 OJ: achieve the desctruction of the temporary -> otherwise it leads to _rRefCount -= 2
+        { // i36686 OJ: achieve the destruction of the temporary -> otherwise it leads to _rRefCount -= 2
             m_xProxyAggregate = xFactory->createProxy( _rxComponent );
         }
         if ( m_xProxyAggregate.is() )
@@ -219,7 +219,7 @@ namespace comphelper
         // append XComponent, coming from WeakComponentImplHelperBase
         sal_Int32 nLen = aTypes.getLength();
         aTypes.realloc( nLen + 1 );
-        aTypes[ nLen ] = ::getCppuType( static_cast< Reference< XComponent >* >( NULL ) );
+        aTypes[ nLen ] = cppu::UnoType<XComponent>::get();
 
         return aTypes;
     }
