@@ -18,7 +18,7 @@
  */
 
 
-#include "comphelper/serviceinfohelper.hxx"
+#include <comphelper/serviceinfohelper.hxx>
 #include <stdarg.h>
 
 // #####################################################################
@@ -27,28 +27,13 @@ namespace comphelper
 {
 
 /** returns an empty UString(). most times sufficient */
-OUString SAL_CALL ServiceInfoHelper::getImplementationName() throw( ::com::sun::star::uno::RuntimeException )
+OUString SAL_CALL ServiceInfoHelper::getImplementationName() throw( ::com::sun::star::uno::RuntimeException, std::exception )
 {
     return OUString();
 }
 
-/** the base implementation iterates over the service names from <code>getSupportedServiceNames</code> */
-sal_Bool SAL_CALL ServiceInfoHelper::supportsService( const OUString& ServiceName ) throw(::com::sun::star::uno::RuntimeException)
-{
-    return supportsService( ServiceName, getSupportedServiceNames() );
-}
-
-sal_Bool SAL_CALL ServiceInfoHelper::supportsService( const OUString& ServiceName, const ::com::sun::star::uno::Sequence< OUString >& SupportedServices ) throw()
-{
-    const OUString * pArray = SupportedServices.getConstArray();
-    for( sal_Int32 i = 0; i < SupportedServices.getLength(); i++ )
-        if( pArray[i] == ServiceName )
-            return sal_True;
-    return sal_False;
-}
-
 /** the base implementation has no supported services */
-::com::sun::star::uno::Sequence< OUString > ServiceInfoHelper::getSupportedServiceNames(void) throw( ::com::sun::star::uno::RuntimeException )
+::com::sun::star::uno::Sequence< OUString > ServiceInfoHelper::getSupportedServiceNames(void) throw( ::com::sun::star::uno::RuntimeException, std::exception )
 {
     ::com::sun::star::uno::Sequence< OUString> aSeq(0);
     return aSeq;
@@ -72,5 +57,4 @@ void ServiceInfoHelper::addToSequence( ::com::sun::star::uno::Sequence< OUString
 
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
